IF EXISTS(SELECT 1 FROM sys.procedures 
          WHERE name = 'RESYNC_PT_DISTRIBUTIONS')
BEGIN
    DROP PROCEDURE dbo.RESYNC_PT_DISTRIBUTIONS
END
GO

CREATE PROCEDURE RESYNC_PT_DISTRIBUTIONS  
    @DOC_Num nvarchar(100),   
    @DOC_Type int,	
	@TRX_Type int,
	@User_ID nvarchar(50)
	
AS   

	DECLARE @bSetGPQTY tinyint;
	DECLARE @Project_ID nvarchar(50);
	DECLARE @SEQ_Line	numeric(19,5);
	DECLARE @SEQUENCE	numeric(19,5);
	DECLARE @ACCTTYPE	int;
	DECLARE @GL_SEQUENCE	numeric(19,5);
	DECLARE @TRX_Amt	numeric(19,5);
	DECLARE @TRX_Unit	numeric(19,5);
	DECLARE @Receipts_Value numeric(19,5);
	DECLARE @SuppresCostDistr tinyint;
	DECLARE @multiplier int;
	DECLARE @LineNumber numeric(19,5);
	
	DECLARE @MessageOutput VARCHAR(100)

	DECLARE @Extended_Price numeric(19,5);
	DECLARE @Extended_Cost numeric(19,5);
	DECLARE @QTY_To_Invoice numeric(19,5);
	DECLARE @Unit_Price numeric(19,5);
	DECLARE @Sales_Index int;
	DECLARE @Markdown_Index int;
	DECLARE @COS_Index int;
	DECLARE @Markdown_Amount numeric(19,5);
	DECLARE @BackoutSales_Amount numeric(19,5);
	DECLARE @QTY numeric(19,5);
	DECLARE @Originating_Markdown_Amount numeric(19,5);
	DECLARE @OriginatingBackoutSales_Amount numeric(19,5);
	DECLARE @DecimalPlacesQtys int;
	DECLARE @LineItemSeqNo numeric(19,5);
	DECLARE @ItemDesc	nvarchar(255);
	DECLARE @ItemNum	nvarchar(100);
	DECLARE @LocCode	nvarchar(100);
	DECLARE @AmountType int;
	DECLARE @ACCT_IDX int;
	DECLARE @Distr_Type int;
	DECLARE @Credit numeric(19,5);
	DECLARE @Debit numeric(19,5);
	DECLARE @QTYOrdered numeric(19,5);
	DECLARE @QTYCancelled numeric(19,5);
	DECLARE @Ord numeric(19,5);
	DECLARE @Dec numeric(19,5);
	DECLARE @DOC_Date date;
	DECLARE @POST_Date date;
	DECLARE @MASTER_ID nvarchar(100);
	DECLARE @MASTER_Name nvarchar(100);
	

	SET NOCOUNT ON;
	SET @SEQUENCE = 16384;

	IF @TRX_Type = 6/*SOP*/
	BEGIN
		select @DOC_Date = DOCDATE, @POST_Date = GLPOSTDT, @MASTER_ID = CUSTNMBR, @MASTER_Name = CUSTNAME from SOP10100 where SOPNUMBE = LTRIM(RTRIM(@DOC_Num))
	END
	ELSE IF @TRX_Type = 7/*POP*/
	BEGIN
		select @DOC_Date = DOCDATE,  @MASTER_ID = VENDORID, @MASTER_Name = VENDNAME 
		from POP10100 where PONUMBER = LTRIM(RTRIM(@DOC_Num))
	END


	/*Reading setup table*/
	SELECT @bSetGPQTY = (CASE WHEN Unit_Default=1/*UNIT_SYNCGPQTY*/ THEN 1 
								WHEN Unit_Default=2/*UNIT_INITGPQTY*/ THEN 1 ELSE 0 END) FROM dbo.ME97710

	/*Getting default project id and last sequence number for PT distribution lines*/
	SELECT TOP 1 @Project_ID = ME_Job_ID FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND DOCTYPE=@DOC_Type 

	IF ISNULL(@Project_ID,'') = ''
	BEGIN
		SELECT @Project_ID = ME_Job_ID FROM ME97736 WHERE USERID = LTRIM(RTRIM(@User_ID))
		IF ISNULL(@Project_ID,'') = ''
		BEGIN
			SET @Project_ID = @User_ID
		END
	END
	

	IF @TRX_Type = 6/*SOP*/
	BEGIN
		DECLARE SOP_LINE_ITEM CURSOR FOR 
			SELECT XTNDPRCE,EXTDCOST,QTYTOINV,UNITPRCE,SLSINDX,MKDNINDX,CSLSINDX,MRKDNAMT,
			BKTSLSAM,QUANTITY,ORMRKDAM,ORBKTSLS,DECPLQTY,LNITMSEQ,ITEMDESC,ITEMNMBR,LOCNCODE 
			FROM dbo.SOP10200	where SOPNUMBE=LTRIM(RTRIM(@DOC_Num)) AND SOPTYPE=@DOC_Type 
						AND CMPNTSEQ=0


		OPEN SOP_LINE_ITEM 

		FETCH NEXT FROM SOP_LINE_ITEM INTO
			@Extended_Price,@Extended_Cost,@QTY_To_Invoice,@Unit_Price,@Sales_Index,@Markdown_Index,
			@COS_Index,@Markdown_Amount,@BackoutSales_Amount,@QTY,@Originating_Markdown_Amount,
			@OriginatingBackoutSales_Amount,@DecimalPlacesQtys,@LineItemSeqNo,@ItemDesc,@ItemNum,
			@LocCode
		
		WHILE @@FETCH_STATUS = 0
		BEGIN
			SET @GL_SEQUENCE = 0;

			/*if @Extended_Price<>0 or (@QTY_To_Invoice<>0 and @Unit_Price<>0)
			BEGIN*/
				SELECT @ACCTTYPE=ACCTTYPE FROM GL00100 WHERE ACTINDX = @Sales_Index
				if @ACCTTYPE<>2 and @ACCTTYPE<>4 
				BEGIN
					SELECT @AmountType = ME_Default_Amount_Type_5 FROM ME97710
					
					IF @DOC_Type=3/*SOP_INVOICE*/ OR @DOC_Type=4/*SOP_RETURN*/ OR @DOC_Type=6/*SOP_FULFILLMENT_ORDER*/
					BEGIN
						SELECT @GL_SEQUENCE=SEQNUMBR FROM SOP10102 WHERE SOPNUMBE=LTRIM(RTRIM(@DOC_Num)) and 
								SOPTYPE=@DOC_Type and DISTTYPE=1/*SOP_DIST_SALES*/ and ACTINDX=@Sales_Index
					END

					/*IF @Markdown_Amount=0 
					BEGIN
						IF @BackoutSales_Amount>0.0
							SET @TRX_Amt = @BackoutSales_Amount;
						ELSE
							SET @TRX_Amt = @Extended_Price;

					END
					ELSE
					BEGIN
						if @DOC_Type=3/*SOP_INVOICE*/
						BEGIN
							IF @BackoutSales_Amount>0.0
								SET @TRX_Amt = @BackoutSales_Amount;
							ELSE
								SET @TRX_Amt = @Extended_Price;

							/*SET @TRX_Amt = @TRX_Amt + @Markdown_Amount*/
						END
						ELSE
							SET @TRX_Amt = @QTY * @Unit_Price;
					END*/

					SET @TRX_Amt = @QTY * @Unit_Price;

					if @bSetGPQTY = 1 
					BEGIN
						if @Extended_Price>=0
							SET @TRX_Unit = @QTY_To_Invoice
						ELSE
							SET @TRX_Unit = @QTY
					END
					
					IF (SELECT COUNT(*) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
							DOCTYPE=@DOC_Type AND ME_Module_LI_Index=@LineItemSeqNo AND
							ME_Amount_Type = @AmountType) > 0 
					BEGIN							
							UPDATE dbo.ME97706 SET TRXAMNT = @TRX_Amt, ACTINDX = @Sales_Index,
							DSCRIPTN = SUBSTRING('('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,1,30),
							DSCRPTN255 = '('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,
							TRXUNIT=@QTY
							WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
							DOCTYPE=@DOC_Type AND ME_Module_LI_Index=@LineItemSeqNo AND
							ME_Amount_Type = @AmountType
					END
					ELSE
					BEGIN
						SELECT @SEQ_Line = ISNULL(MAX(LNITMSEQ),0) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND DOCTYPE=@DOC_Type

						INSERT INTO dbo.ME97706(ME_Job_ID,DOCNUMBR,DOCTYPE,ORIGAMT,ME_Job_Status,ME_Document_Number_WORK,LNITMSEQ,
						ME_GL_Distribution_LI_In,ME_Module_LI_Index,ME_Amount_Type,TRXAMNT,TRXUNIT,
						DECPLQTY,ME_Trx_Type,ME_Originating_Master_ID,DOCDATE,GLPOSTDT,ACTINDX,
						DSCRIPTN,DSCRPTN255,ME_Originating_Mstr_Name)
						SELECT @Project_ID,@DOC_Num,@DOC_Type,@TRX_Amt,1,SUBSTRING(@DOC_Num,1,17),@SEQ_Line+@SEQUENCE,
							@GL_SEQUENCE,@LineItemSeqNo,@AmountType,@TRX_Amt,@QTY,@DecimalPlacesQtys,
							@TRX_Type,@MASTER_ID,@DOC_Date,@POST_Date,@Sales_Index,
							SUBSTRING('('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,1,30), '('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,
							@MASTER_Name
					END
				END
			/*END*/

			IF @Markdown_Amount<>0
			BEGIN
				SELECT @ACCTTYPE=ACCTTYPE FROM GL00100 WHERE ACTINDX = @Markdown_Index
				if @ACCTTYPE<>2 and @ACCTTYPE<>4 
				BEGIN
					SELECT @AmountType = 2/*ME_AMTTYPE_TRADEDISC*/

					IF @DOC_Type=3/*SOP_INVOICE*/ OR @DOC_Type=4/*SOP_RETURN*/ 
					BEGIN
						SELECT @GL_SEQUENCE=SEQNUMBR FROM SOP10102 WHERE SOPNUMBE=LTRIM(RTRIM(@DOC_Num)) and 
								SOPTYPE=@DOC_Type and DISTTYPE=10/*SOP_DIST_MARK*/ and ACTINDX=@Markdown_Index
					END

					IF (SELECT COUNT(*) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
							DOCTYPE=@DOC_Type AND ME_Module_LI_Index=@LineItemSeqNo AND
							ME_Amount_Type = @AmountType) > 0 
					BEGIN							
							UPDATE dbo.ME97706 SET TRXAMNT = -1 * @Markdown_Amount*@QTY, ACTINDX = @Markdown_Index,
							DSCRIPTN = SUBSTRING('('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,1,30),
							DSCRPTN255 = '('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,
							TRXUNIT=@QTY
							WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
							DOCTYPE=@DOC_Type AND ME_Module_LI_Index=@LineItemSeqNo AND
							ME_Amount_Type = @AmountType
					END
					ELSE
					BEGIN
						SELECT @SEQ_Line = ISNULL(MAX(LNITMSEQ),0) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND DOCTYPE=@DOC_Type

						INSERT INTO dbo.ME97706(ME_Job_ID,DOCNUMBR,DOCTYPE,ORIGAMT,ME_Job_Status,ME_Document_Number_WORK,LNITMSEQ,
						ME_GL_Distribution_LI_In,ME_Module_LI_Index,ME_Amount_Type,TRXAMNT,TRXUNIT,
						DECPLQTY,ME_Trx_Type,ME_Originating_Master_ID,DOCDATE,GLPOSTDT,ACTINDX,
						DSCRIPTN,DSCRPTN255,ME_Originating_Mstr_Name)
						SELECT @Project_ID,@DOC_Num,@DOC_Type,-1*@Markdown_Amount*@QTY,0,SUBSTRING(@DOC_Num,1,17),@SEQ_Line+@SEQUENCE,
							@GL_SEQUENCE,@LineItemSeqNo,@AmountType,-1 * @Markdown_Amount*@QTY,@QTY,@DecimalPlacesQtys,
							@TRX_Type,@MASTER_ID,@DOC_Date,@POST_Date,@Markdown_Index,
							SUBSTRING('('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,1,30), '('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,
							@MASTER_Name
					END
					
				END
			END
			ELSE
			BEGIN
				delete from ME97706  WHERE DOCNUMBR = LTRIM(RTRIM(@DOC_Num)) and ME_Amount_Type = 2	
					and 0 = (select sum(MRKDNAMT) from SOP10200 where SOPNUMBE = LTRIM(RTRIM(@DOC_Num))	
									and LNITMSEQ = ME97706.ME_Module_LI_Index)
			END

			SELECT @Receipts_Value = SUM(UNITCOST) FROM IV10200 WHERE ITEMNMBR= LTRIM(RTRIM(@ItemNum)) AND 
										TRXLOCTN=LTRIM(RTRIM(@LocCode))
									AND RCPTSOLD = 0

		

			if @Receipts_Value<>0 or @DOC_Type=2/*Orders*/ or @DOC_Type=3/*Invoice*/ or @DOC_Type=4/*SOP_RETURN*/
			BEGIN
				SELECT @ACCTTYPE=ACCTTYPE FROM GL00100 WHERE ACTINDX = @COS_Index
				if @ACCTTYPE<>2 and @ACCTTYPE<>4 
				BEGIN
					SELECT @SuppresCostDistr = ME_Suppress_Dist_Line FROM ME97710
					IF @SuppresCostDistr = 0 or (@SuppresCostDistr = 1 AND @Extended_Cost>0)
					BEGIN
						SELECT @AmountType = ME_Default_Amount_Type_10 FROM ME97710
						IF @DOC_Type=3/*SOP_INVOICE*/ OR @DOC_Type=4/*SOP_RETURN*/ OR @DOC_Type=6/*SOP_FULFILLMENT_ORDER*/
						BEGIN
							SELECT @GL_SEQUENCE=SEQNUMBR FROM SOP10102 WHERE SOPNUMBE=LTRIM(RTRIM(@DOC_Num)) and 
									SOPTYPE=@DOC_Type and DISTTYPE=14/*SOP_DIST_COGS*/ and ACTINDX=@COS_Index
						END
							
						IF (SELECT COUNT(*) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
							DOCTYPE=@DOC_Type AND ME_Module_LI_Index=@LineItemSeqNo AND
							ME_Amount_Type = @AmountType) > 0 
						BEGIN							
								UPDATE dbo.ME97706 SET TRXAMNT = @Extended_Cost, ACTINDX = @COS_Index,
								DSCRIPTN = SUBSTRING('('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,1,30),
								DSCRPTN255 = '('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,
								TRXUNIT=@QTY
								WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
								DOCTYPE=@DOC_Type AND ME_Module_LI_Index=@LineItemSeqNo AND
								ME_Amount_Type = @AmountType
						END
						ELSE
						BEGIN
							SELECT @SEQ_Line = ISNULL(MAX(LNITMSEQ),0) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND DOCTYPE=@DOC_Type

							INSERT INTO dbo.ME97706(ME_Job_ID,DOCNUMBR,DOCTYPE,ORIGAMT,ME_Job_Status,ME_Document_Number_WORK,LNITMSEQ,
							ME_GL_Distribution_LI_In,ME_Module_LI_Index,ME_Amount_Type,TRXAMNT,TRXUNIT,
							DECPLQTY,ME_Trx_Type,ME_Originating_Master_ID,DOCDATE,GLPOSTDT,ACTINDX,
							DSCRIPTN,DSCRPTN255,ME_Originating_Mstr_Name)
							SELECT @Project_ID,@DOC_Num,@DOC_Type,@Extended_Cost,1,SUBSTRING(@DOC_Num,1,17),@SEQ_Line+@SEQUENCE,
								@GL_SEQUENCE,@LineItemSeqNo,@AmountType,@Extended_Cost,@QTY,@DecimalPlacesQtys,
								@TRX_Type,@MASTER_ID,@DOC_Date,@POST_Date,@COS_Index,
								SUBSTRING('('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,1,30), '('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,
								@MASTER_Name
						END
						
					END
				END
			END


			FETCH NEXT FROM SOP_LINE_ITEM INTO
			@Extended_Price,@Extended_Cost,@QTY_To_Invoice,@Unit_Price,@Sales_Index,@Markdown_Index,
			@COS_Index,@Markdown_Amount,@BackoutSales_Amount,@QTY,@Originating_Markdown_Amount,
			@OriginatingBackoutSales_Amount,@DecimalPlacesQtys,@LineItemSeqNo,@ItemDesc,@ItemNum,
			@LocCode
		END
		CLOSE SOP_LINE_ITEM
		DEALLOCATE SOP_LINE_ITEM

		IF @DOC_Type=3/*SOP_INVOICE*/ OR @DOC_Type=4/*SOP_RETURN*/ 
		BEGIN
			DECLARE SOP_DISTR_WORK_HIST CURSOR FOR 
						SELECT ACTINDX,DISTTYPE,CRDTAMNT,DEBITAMT,SEQNUMBR FROM SOP10102 
									WHERE SOPNUMBE=LTRIM(RTRIM(@DOC_Num)) AND SOPTYPE=@DOC_Type
										AND DISTTYPE NOT IN (14,1,10,2,5,15,16,17,18,19,11,12) AND
										DistRef <> '**'


			OPEN SOP_DISTR_WORK_HIST 

			FETCH NEXT FROM SOP_DISTR_WORK_HIST INTO
				@ACCT_IDX,@Distr_Type,@Credit,@Debit,@LineItemSeqNo
		
			WHILE @@FETCH_STATUS = 0
			BEGIN
				SELECT @ACCTTYPE=ACCTTYPE FROM GL00100 WHERE ACTINDX = @ACCT_IDX
				if @ACCTTYPE<>2 and @ACCTTYPE<>4 
				BEGIN
					SET @AmountType = (CASE WHEN @Distr_Type=7 THEN 3 
											WHEN @Distr_Type=8 THEN 4 
											WHEN @Distr_Type=9 THEN 5
											WHEN @Distr_Type=6 OR @Distr_Type=10 OR @Distr_Type=4 THEN 2
											WHEN @Distr_Type=3 OR @Distr_Type=21 THEN 11
											WHEN @Distr_Type=14 THEN (SELECT  ME_Default_Amount_Type_10 FROM ME97710)
											ELSE (SELECT  ME_Default_Amount_Type_5 FROM ME97710)
											END)

					SET @multiplier = (CASE WHEN @Distr_Type = 3 OR @Distr_Type=4 OR 
													@Distr_Type=6 OR @Distr_Type=21 THEN -1 ELSE 1 END)
					
					SET @ItemDesc = (CASE WHEN @Distr_Type=7 THEN 'Freight' 
											WHEN @Distr_Type=8 THEN 'Miscellaneous' 
											WHEN @Distr_Type=6 THEN 'Trade Discount' 
											WHEN @Distr_Type=9 THEN 'Sales Tax' ELSE '' END)

					if @DOC_Type<>4/*SOP_RETURN*/
						SET @TRX_Amt = (@Credit-@Debit)
					ELSE
						SET @TRX_Amt = (@Debit-@Credit)
					
					IF @Distr_Type<>6
						SET @TRX_Amt = @multiplier*@TRX_Amt

					IF (SELECT COUNT(*) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
							DOCTYPE=@DOC_Type AND ME_Module_LI_Index=0 AND
							ME_Amount_Type = @AmountType AND ACTINDX=@ACCT_IDX) > 0 
					BEGIN							
							UPDATE dbo.ME97706 SET TRXAMNT = @TRX_Amt,
							ME_GL_Distribution_LI_In = @LineItemSeqNo													
							WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
							DOCTYPE=@DOC_Type AND ME_Module_LI_Index=0 AND
							ME_Amount_Type = @AmountType AND  ACTINDX=@ACCT_IDX
					END
					ELSE
					BEGIN
						SELECT @SEQ_Line = ISNULL(MAX(LNITMSEQ),0) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND DOCTYPE=@DOC_Type

						INSERT INTO dbo.ME97706(ME_Job_ID,DOCNUMBR,DOCTYPE,ORIGAMT,ME_Job_Status,ME_Document_Number_WORK,LNITMSEQ,
						ME_GL_Distribution_LI_In,ME_Module_LI_Index,ME_Amount_Type,TRXAMNT,TRXUNIT,
						DECPLQTY,ME_Trx_Type,ME_Originating_Master_ID,DOCDATE,GLPOSTDT,ACTINDX,
						DSCRIPTN,DSCRPTN255,ME_Originating_Mstr_Name)
						SELECT @Project_ID,@DOC_Num,@DOC_Type,@TRX_Amt,1,SUBSTRING(@DOC_Num,1,17),@SEQ_Line+@SEQUENCE,
							@LineItemSeqNo,0,@AmountType,@TRX_Amt,0,0,
							@TRX_Type,@MASTER_ID,@DOC_Date,@POST_Date,@ACCT_IDX,
							@ItemDesc, @ItemDesc,
							@MASTER_Name
					END


				END


				FETCH NEXT FROM SOP_DISTR_WORK_HIST INTO
				@ACCT_IDX,@Distr_Type,@Credit,@Debit,@LineItemSeqNo
			END
			CLOSE SOP_DISTR_WORK_HIST
			DEALLOCATE SOP_DISTR_WORK_HIST
		END
		ELSE IF @DOC_Type=2/*SOP_ORDER*/ 
		BEGIN
			DECLARE SOP_PYMT_WORK_HIST CURSOR FOR 
			SELECT DEPINDEX,AMNTPAID
			FROM dbo.SOP10103	where SOPNUMBE=LTRIM(RTRIM(@DOC_Num)) AND SOPTYPE=@DOC_Type 
						


			OPEN SOP_PYMT_WORK_HIST 

			FETCH NEXT FROM SOP_PYMT_WORK_HIST INTO
				@ACCT_IDX,@TRX_Amt
		
			WHILE @@FETCH_STATUS = 0
			BEGIN
				SELECT @ACCTTYPE=ACCTTYPE FROM GL00100 WHERE ACTINDX = @ACCT_IDX
				if @ACCTTYPE<>2 and @ACCTTYPE<>4 
				BEGIN
					SELECT @AmountType = 11/*ME_AMTTYPE_CASH*/

					IF (SELECT COUNT(*) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
							DOCTYPE=@DOC_Type AND ME_Module_LI_Index=0 AND
							ME_Amount_Type = @AmountType) > 0 
					BEGIN							
							UPDATE dbo.ME97706 SET TRXAMNT = @TRX_Amt, ACTINDX = @ACCT_IDX,
							DSCRIPTN = 'Deposits',
							DSCRPTN255 = 'Deposits'
							
							WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
							DOCTYPE=@DOC_Type AND ME_Module_LI_Index=0 AND
							ME_Amount_Type = @AmountType
					END
					ELSE
					BEGIN
						SELECT @SEQ_Line = ISNULL(MAX(LNITMSEQ),0) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND DOCTYPE=@DOC_Type

						INSERT INTO dbo.ME97706(ME_Job_ID,DOCNUMBR,DOCTYPE,ORIGAMT,ME_Job_Status,ME_Document_Number_WORK,LNITMSEQ,
						ME_GL_Distribution_LI_In,ME_Module_LI_Index,ME_Amount_Type,TRXAMNT,TRXUNIT,
						DECPLQTY,ME_Trx_Type,ME_Originating_Master_ID,DOCDATE,GLPOSTDT,ACTINDX,
						DSCRIPTN,DSCRPTN255,ME_Originating_Mstr_Name)
						SELECT @Project_ID,@DOC_Num,@DOC_Type,@TRX_Amt,1,SUBSTRING(@DOC_Num,1,17),@SEQ_Line+@SEQUENCE,
							0,0,@AmountType,@TRX_Amt,0,0,
							@TRX_Type,@MASTER_ID,@DOC_Date,@POST_Date,@ACCT_IDX,
							'Deposits', 'Deposits',
							@MASTER_Name
					END

				END
					

				FETCH NEXT FROM SOP_PYMT_WORK_HIST INTO
				@ACCT_IDX,@TRX_Amt
			END
			CLOSE SOP_PYMT_WORK_HIST
			DEALLOCATE SOP_PYMT_WORK_HIST
		END


		delete from ME97706  WHERE DOCNUMBR = LTRIM(RTRIM(@DOC_Num)) and DOCTYPE = @DOC_Type and ME_Module_LI_Index > 0 
			and not exists (select * from SOP10200 where SOPNUMBE = LTRIM(RTRIM(@DOC_Num))
							and LNITMSEQ = ME97706.ME_Module_LI_Index )


		delete from ME97706  
			WHERE DOCNUMBR = LTRIM(RTRIM(@DOC_Num)) and DOCTYPE = @DOC_Type and ME_Module_LI_Index = 0 
				and not exists (select * from SOP10102 where SOPNUMBE = LTRIM(RTRIM(@DOC_Num))
				and SEQNUMBR = ME97706.ME_GL_Distribution_LI_In and ACTINDX = ME97706.ACTINDX)
				and not exists (select * from SOP10103 where SOPNUMBE = LTRIM(RTRIM(@DOC_Num)))


	END
	ELSE IF @TRX_Type = 7/*POP*/
	BEGIN
		DECLARE POP_LINE CURSOR FOR 
		SELECT LineNumber,EXTDCOST,INVINDX,QTYORDER,QTYCANCE,DECPLQTY,ORD,ITEMDESC
		FROM dbo.POP10110	where PONUMBER=LTRIM(RTRIM(@DOC_Num)) 

		OPEN POP_LINE 

		FETCH NEXT FROM POP_LINE INTO
			@LineNumber,@Extended_Cost,@ACCT_IDX,@QTYOrdered,@QTYCancelled,@DecimalPlacesQtys,@Ord,
			@ItemDesc
		
		WHILE @@FETCH_STATUS = 0
		BEGIN
			IF @LineNumber<>0 and @Extended_Cost<>0 
			BEGIN
				SELECT @ACCTTYPE=ACCTTYPE FROM GL00100 WHERE ACTINDX = @ACCT_IDX
				if @ACCTTYPE<>2 and @ACCTTYPE<>4 
				BEGIN
					SELECT @AmountType = ME_Default_Amount_Type_6 FROM ME97710

					SET @QTY = @QTYOrdered-@QTYCancelled

					if @bSetGPQTY = 1 
					BEGIN
	
						SET @Dec = @DecimalPlacesQtys
							SET @TRX_Unit = @QTY
					END

					IF (SELECT COUNT(*) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
							DOCTYPE=@DOC_Type AND ME_Module_LI_Index=@Ord) > 0 
					BEGIN							
							UPDATE dbo.ME97706 SET TRXAMNT = @Extended_Cost, ACTINDX = @ACCT_IDX,
							DSCRIPTN = SUBSTRING('('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,1,30),
							DSCRPTN255 = '('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,
							TRXUNIT=@QTY
							WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND 
							DOCTYPE=@DOC_Type AND ME_Module_LI_Index=@Ord
					END
					ELSE
					BEGIN
						SELECT @SEQ_Line = ISNULL(MAX(LNITMSEQ),0) FROM dbo.ME97706 WHERE DOCNUMBR=LTRIM(RTRIM(@DOC_Num)) AND DOCTYPE=@DOC_Type

						INSERT INTO dbo.ME97706(ME_Job_ID,DOCNUMBR,DOCTYPE,ORIGAMT,ME_Job_Status,ME_Document_Number_WORK,LNITMSEQ,
						ME_GL_Distribution_LI_In,ME_Module_LI_Index,ME_Amount_Type,TRXAMNT,TRXUNIT,
						DECPLQTY,ME_Trx_Type,ME_Originating_Master_ID,DOCDATE,ACTINDX,
						DSCRIPTN,DSCRPTN255,ME_Originating_Mstr_Name)
						SELECT @Project_ID,@DOC_Num,@DOC_Type,@Extended_Cost,1,SUBSTRING(@DOC_Num,1,17),@SEQ_Line+@SEQUENCE,
							0,@Ord,@AmountType,@Extended_Cost,@QTY,@DecimalPlacesQtys,
							@TRX_Type,@MASTER_ID,@DOC_Date,@ACCT_IDX,
							SUBSTRING('('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,1,30), '('+(SELECT LTRIM(STR(@QTY,8,@DecimalPlacesQtys)))+')'+@ItemDesc,
							@MASTER_Name
					END

				END
			END
			
			
			FETCH NEXT FROM POP_LINE INTO
				@LineNumber,@Extended_Cost,@ACCT_IDX,@QTYOrdered,@QTYCancelled,@DecimalPlacesQtys,@Ord,
				@ItemDesc
		END
		CLOSE POP_LINE
		DEALLOCATE POP_LINE



		delete from ME97706  WHERE DOCNUMBR = LTRIM(RTRIM(@DOC_Num))  and DOCTYPE = @DOC_Type 	
		and not exists (select * from POP10110 WHERE PONUMBER = LTRIM(RTRIM(@DOC_Num))	
		and ME97706.ME_Module_LI_Index = POP10110.ORD)
		
	END
	/*ELSE IF @TRX_Type = 10/*POP Receipts*/ OR  @TRX_Type = 16/*POP Returns*/
	BEGIN
		SELECT 'POP Receipts and Returns'
	END
	ELSE IF @TRX_Type = 13/*POP Match*/
	BEGIN
		SELECT 'POP Match'
	END*/



    SET NOCOUNT OFF;
GO 

