/* This script creates TWO stored procedures:
[EBS_PT_ValidateInsert_ME97705]
[EBS_PT_VALIDATE_ME97705]

It is expected that customers will only call the [EBS_PT_ValidateInsert_ME97705] as it runs the [EBS_PT_VALIDATE_ME97705] script.
As the name implies, it works validates a potential insert into the ME97705 (ME_Job_Cost_TRX_OPEN) table

Note: There is a spreasheet with helpful information for working with this script: PTValidationErrors.xlsx


Due to the large number of parameters it is recommended that you explictly set the parameters you actually want to use.
Let the script set the other fields to default values.
Example:
declare @O_iErrorState		int				
declare	@oErrString		varchar(255)	
declare	@oErrStringAll	varchar(255)	

EXEC dbo.[EBS_PT_ValidateInsert_ME97705] @O_iErrorState OUT, @oErrString OUT, @oErrStringAll OUT,  
							@I_vME_Job_ID = 'POP', @I_vME_Trx_Type = 4, @I_vDOCNUMBR = '70', @I_vTRXAMNT = 88.33,
							@I_vACTINDX = 111

select @O_iErrorState, @oErrString, @oErrStringAll


*/


/****** Object:  StoredProcedure [dbo].[EBS_PT_VALIDATE_ME97705]    Script Date: 05/09/2013 14:23:16 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO



--ME_Job_Cost_TRX_WORK
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[EBS_PT_VALIDATE_ME97705]') AND type in (N'P', N'PC'))
DROP PROCEDURE [dbo].[EBS_PT_VALIDATE_ME97705]
GO


CREATE PROCEDURE [dbo].[EBS_PT_VALIDATE_ME97705] --ME_Job_Cost_TRX_WORK

	@O_iErrorState		int				OUT,
	@oErrString			varchar(255)	OUT,
	@oErrStringAll		varchar(255)	OUT,
	
	@I_vME_Job_ID		varchar(15)		= '',
	@I_vME_Trx_Type		int				= 0,
	@I_vDistType		int				= 0,
	@I_vLNITMSEQ		int				= 0,
	@I_vSQNCLINE		numeric(19, 5)	= 0,
	@I_vDOCDATE			datetime		= '01/01/1900',
	@I_vGLPOSTDT		datetime		= '01/01/1900',
	
	@I_vACTINDX						int				= 0,
	@I_vDOCNUMBR					varchar(21)		= '', 
	@I_vDOCTYPE						int				= 0,
	@I_vME_GL_Distribution_LI_In	int				= 0,
	@I_vME_Module_LI_Index			int				= 0,
	@I_vME_Document_Number_WORK		varchar(17)		= '', 
	
	@I_vDSCRIPTN					varchar(31)		= '', 
	@I_vDSCRPTN255					varchar(255)	= '', 

	@I_vTRXAMNT						numeric(19, 5)	= 0,
	@I_vORIGAMT						numeric(19, 5)	= 0,
	@I_vME_Breakdown_Code			varchar(15)		= '', 
	@I_vME_Amount_Type				int				= 0,
	@I_vME_Originating_Master_ID	varchar(31)		= '', 
	@I_vME_Originating_Mstr_Name	varchar(65)		= '', 
	@I_vJRNENTRY					int				= 0,
	
	@I_vME_User_Defined		varchar(15)		= '', 
	@I_vMEuserdefined1		varchar(15)		= '',  
	@I_vMEuserdefined2		varchar(15)		= '', 
	@I_vMEuserdefined3		varchar(15)		= '', 
	@I_vME_User_Defined_5	varchar(15)		= '', 
	@I_vME_User_Defined_6	varchar(15)		= '', 
	@I_vME_User_Defined_7	varchar(15)		= '', 

	@I_vME_Work_Order_Number		varchar(21)		= '', 
	@I_vME_Proposal_Number			varchar(15)		= '', 

	@I_vCOMMNTID					varchar(15)		= '', 
	@I_vHOURSWKD					int				= 0,
	@I_vORIGPONUMBER				varchar(17)		= '', 	
	@I_vVOIDED						int				= 0,
	@I_vME_Job_Status				int				= 0,
	@I_vGRANTID						varchar(15)		= ''
AS

DECLARE	
	@oErrStringTemp	varchar(255)

SET NOCOUNT ON
SET @O_iErrorState = 0
SET @oErrString = 'No Errors'
SET @oErrStringAll = ''


/*Sequence Line (@I_vSQNCLINE) validations */
IF @I_vSQNCLINE <> 0 AND @I_vME_Trx_Type = 4 AND FLOOR(@I_vSQNCLINE/500) <> @I_vSQNCLINE/500
	BEGIN
		SET @O_iErrorState = 50
		SET @oErrString = 'Sequence line(SQNCLINE) must be in multiples of 500'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
IF @I_vSQNCLINE <> 0 AND @I_vME_Trx_Type <> 4 
	BEGIN
		SET @O_iErrorState = 51
		SET @oErrString = 'Sequence line(SQNCLINE) is only used on GL Adjustment transactions'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END
IF @I_vSQNCLINE = 0 AND @I_vDOCNUMBR <> '' AND @I_vDOCTYPE <> '' AND @I_vME_Trx_Type = 4   
	BEGIN
		/* Return error if @I_vSQNCLINE isn't specified and can't be determined */
		IF NOT EXISTS (SELECT * FROM GL10000 /*GL_TRX_HDR_WORK*/ WHERE JRNENTRY =  case when ISNUMERIC(@I_vDOCNUMBR) = 1 then @I_vDOCNUMBR else 0 end) 
			BEGIN
				SET @O_iErrorState = 52
				SET @oErrString = 'SQNCLINE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 4(GL Adjustment)'
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END
	END 
	
	
/*Line Item Sequence (@I_vLNITMSEQ) validation */
IF @I_vLNITMSEQ NOT IN (0,16384) AND @I_vME_Trx_Type = 4   
	BEGIN
		SET @O_iErrorState = 53
		SET @oErrString = 'Line Item Sequenc(LNITMSEQ) must = 16384 for GL Adjustment transactions'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 

/*@I_vME_Module_LI_Index validation -  must be specified for inventory transactions*/
IF @I_vME_Module_LI_Index = 0 AND @I_vME_Trx_Type = 11   
	BEGIN
		SET @O_iErrorState = 57
		SET @oErrString = '@ME_Module_LI_Index parameter must be specifed for Inventory transactons (with the LNSEQNBR)'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 

 
 
/* Primary Key validation: DOCNUMBR, DOCTYPE, Sequence line, line item sequence, ME_Amount_type */
IF @I_vDOCNUMBR <> '' AND @I_vDOCTYPE <> '' AND @I_vLNITMSEQ <> 0 AND @I_vME_Amount_Type <> 0
	BEGIN
		SET @oErrStringTemp = ''	
		IF EXISTS(SELECT * FROM ME97705 WHERE DOCNUMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE AND SQNCLINE = @I_vSQNCLINE AND LNITMSEQ = @I_vLNITMSEQ AND  ME_Amount_Type = @I_vME_Amount_Type)
			SET @oErrStringTemp = 'Primary Key (DOCNUMBR,DOCTYPE,SQNCLINE,LNITMSEQ,ME_Amount_Type) violation in the ME97705 table'
		IF EXISTS(SELECT * FROM ME97705 WHERE DOCNUMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE AND SQNCLINE = @I_vSQNCLINE AND LNITMSEQ = @I_vLNITMSEQ AND  ME_Amount_Type = @I_vME_Amount_Type)
			SET @oErrStringTemp = 'Primary Key (DOCNUMBR,DOCTYPE,SQNCLINE,LNITMSEQ,ME_Amount_Type) violation in the ME97705 table'
		IF EXISTS(SELECT * FROM ME97704 WHERE DOCNUMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE AND SQNCLINE = @I_vSQNCLINE AND LNITMSEQ = @I_vLNITMSEQ AND  ME_Amount_Type = @I_vME_Amount_Type)
			SET @oErrStringTemp = 'Primary Key (DOCNUMBR,DOCTYPE,SQNCLINE,LNITMSEQ,ME_Amount_Type) violation in the ME97704 table'
		IF @oErrStringTemp <> ''  --If any error identified above, then return error 
			BEGIN
				SET @oErrString = @oErrStringTemp
				SET @O_iErrorState = 54
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END 


/*@I_vME_Job_ID:  DOES the project exists in the ME_Job_Cost_OPEN */
IF NOT EXISTS (SELECT * FROM ME97708 WHERE ME_Job_ID = @I_vME_Job_ID) 
	BEGIN
		SET @O_iErrorState = 55
		SET @oErrString = 'ME_Job_ID: Project ' + RTRIM(@I_vME_Job_ID) + ' does not exist'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 


/*@I_vDOCNUMBR:  Is a requried field */
IF @I_vDOCNUMBR = ''  
	BEGIN
		SET @O_iErrorState = 56
		SET @oErrString = 'DOCNUMBR is a required field.'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 


/*@I_vME_Trx_Type:  one of the valid ones?
	1 = AP Voucher
	2 = AR Invoice
	3 = Invoicing Invoice
	4 = GL Adjustment
	5 = Project Tracking Adjustments
	6 = Sales Order
	7 = Purchase Order
	8 = Payroll Check
	9 = Cash Receipt
	10 = Purchase Order Receipt
	11 = Inventory Adjustment
	12 = Bank Rec. Transaction
	13 = Purchase Order Invoice
	14 = Time Entry
	15 = Contract Bill  */
IF @I_vME_Trx_Type <= 0 OR @I_vME_Trx_Type >= 16 
	BEGIN
		SET @O_iErrorState = 61
		SET @oErrString = 'ME_Trx_Type must be between 1 and 15'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 


/*@I_vME_Breakdown_Code:  DOES the breakdown code exists in the ME_Breakdown_Maintenance */
IF @I_vME_Breakdown_Code <> '' AND NOT EXISTS (SELECT * FROM ME97723 WHERE ME_Breakdown_Code = @I_vME_Breakdown_Code) 
	BEGIN
		SET @O_iErrorState = 62
		SET @oErrString = 'Breakdown ' + RTRIM(@I_vME_Breakdown_Code) + ' does not exist'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
IF @I_vME_Breakdown_Code = '' AND @I_vME_Trx_Type = 5 
	BEGIN
		SET @O_iErrorState = 63
		SET @oErrString = 'Breakdown code must be specified for PT Adjustment Transactions'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 


/* Checking whether @I_vDOCTYPE, @I_vME_Originating_Master_ID, DOCDATE, ME_GL_Distribution_LI_In ARE valid...
	The answer depends on combination with Trx_Type (that is which module) */
SET @oErrStringTemp = ''
IF @I_vME_Trx_Type = 1  -- AP Voucher
	BEGIN
		IF @I_vDOCTYPE NOT BETWEEN 1 AND 5   
			BEGIN
				SET @oErrString = 'DOCTYPE must be between 1 and 5 for @I_vME_Trx_Type = 1(AP Voucher)' 
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vME_Originating_Master_ID <> '' AND NOT EXISTS (SELECT * FROM PM00200 /*PM_Vendor_MSTR*/ WHERE VENDORID = @I_vME_Originating_Master_ID)  
			BEGIN
				SET @oErrString = 'ME_Originating_Master_ID must a valid Vendor(VENDORID) for @I_vME_Trx_Type = 1(AP Voucher)'
				SET @O_iErrorState = 65
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 

		/*IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM PM10000 /*PM_Transaction_WORK*/ WHERE VCHRNMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE)  */
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS 
				(SELECT VCHRNMBR FROM PM10000 /*PM_Transaction_WORK*/ WHERE VCHRNMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE  
					union all
				 SELECT VCHRNMBR FROM PM20000 /*PM_Transaction_OPEN*/ WHERE VCHRNMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 1(AP Voucher)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		/*IF @I_vME_GL_Distribution_LI_In = 0 AND NOT EXISTS (SELECT * FROM PM20000 /*PM_Transaction_OPEN*/ WHERE VCHRNMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE)  */
		IF @I_vME_GL_Distribution_LI_In = 0 AND NOT EXISTS  
				(SELECT VCHRNMBR FROM PM10000 /*PM_Transaction_WORK*/ WHERE VCHRNMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE  
					union all
				 SELECT VCHRNMBR FROM PM20000 /*PM_Transaction_OPEN*/ WHERE VCHRNMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE)  
			BEGIN
				SET @oErrString = 'ME_GL_Distribution_LI_In must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 1(AP Voucher)'
				SET @O_iErrorState = 67
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		/*IF @I_vME_Module_LI_Index <> 0  -- No error message, we will just reset to zero  */  
	END 

IF @I_vME_Trx_Type = 2  -- AR Invoice
	BEGIN
		IF @I_vDOCTYPE NOT BETWEEN 1 AND 8 --'RM Document Type-All' of table RM_Sales_WORK
			BEGIN
				SET @oErrString = 'DOCTYPE must be between 1 and 8 for @I_vME_Trx_Type = 2(AR Invoice)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vME_Originating_Master_ID <> '' AND NOT EXISTS (SELECT * FROM RM00101 /*RM_Customer_MSTR*/ WHERE CUSTNMBR = @I_vME_Originating_Master_ID)  
			BEGIN
				SET @oErrString = 'ME_Originating_Master_ID must a valid Customer(CUSTNMBR) for @I_vME_Trx_Type = 2(AR Invoice)'
				SET @O_iErrorState = 65
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM RM00401 /*RM_Keys_MSTR*/ WHERE DOCNUMBR = @I_vDOCNUMBR AND RMDTYPAL = @I_vDOCTYPE)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 2(AR Invoice)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END 
IF @I_vME_Trx_Type = 3  -- Invoicing Invoice
	BEGIN
		IF @I_vDOCTYPE NOT BETWEEN 1 AND 2 --'Document Type' of table IVC_HDR_WORK
			BEGIN
				SET @oErrString = 'DOCTYPE must be either 1 or 2 when @I_vME_Trx_Type = 3(Invoicing Invoice)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vME_Originating_Master_ID <> '' AND NOT EXISTS (SELECT * FROM RM00101 /*RM_Customer_MSTR*/ WHERE CUSTNMBR = @I_vME_Originating_Master_ID)  
			BEGIN
				SET @oErrString = 'ME_Originating_Master_ID must a valid Customer(CUSTNMBR) for @I_vME_Trx_Type = 3(Invoicing Invoice)'
				SET @O_iErrorState = 65
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM IVC10100 /*IVC_HDR_WORK*/ WHERE INVCNMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 3(Invoicing Invoice)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END 
IF @I_vME_Trx_Type = 4  -- GL Adjustment
	BEGIN
		IF @I_vDOCTYPE <> 0  
			BEGIN
				SET @oErrString = 'DOCTYPE must be 0 for @I_vME_Trx_Type = 4(GL Adjustment)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM GL10000 /*GL_TRX_HDR_WORK*/ WHERE JRNENTRY = case when ISNUMERIC(@I_vDOCNUMBR) = 1 then @I_vDOCNUMBR else 0 end)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 4(GL Adjustment)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END
	END 
/*IF @I_vME_Trx_Type = 5  -- Project Tracking Adjustments*/
	/*ME_Originating_Master_ID is not validated for PT Adjustments */
IF @I_vME_Trx_Type = 6  -- Sales Order
	BEGIN
		IF @I_vDOCTYPE NOT BETWEEN 1 AND 6  --'SOP Type' of table SOP_HDR_WORK
			BEGIN
				SET @oErrString = 'DOCTYPE must be between 1 and 6 for @I_vME_Trx_Type = 6(Sales Order)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vME_Originating_Master_ID <> '' AND NOT EXISTS (SELECT * FROM RM00101 /*RM_Customer_MSTR*/ WHERE CUSTNMBR = @I_vME_Originating_Master_ID)  
			BEGIN
				SET @oErrString = 'ME_Originating_Master_ID must a valid Customer(CUSTNMBR) for @I_vME_Trx_Type = 6(Sales Order)'
				SET @O_iErrorState = 65
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM SOP10100 /*SOP_HDR_WORK*/ WHERE SOPNUMBE = @I_vDOCNUMBR AND SOPTYPE = @I_vDOCTYPE)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 6(Sales Order)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END
	END 
IF @I_vME_Trx_Type = 7  -- Purchase Order
	BEGIN
		IF @I_vDOCTYPE NOT BETWEEN 1 AND 4   --'PO Type'  
			BEGIN
				SET @oErrString = 'DOCTYPE must be between 1 and 4 for @I_vME_Trx_Type = 7(Purchase Order)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vME_Originating_Master_ID <> '' AND NOT EXISTS (SELECT * FROM PM00200 /*PM_Vendor_MSTR*/ WHERE VENDORID = @I_vME_Originating_Master_ID)  
			BEGIN
				SET @oErrString = 'ME_Originating_Master_ID must a valid Vendor(VENDORID) for @I_vME_Trx_Type = 7(Purchase Order)'
				SET @O_iErrorState = 65
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM POP10100 /*POP_PO*/ WHERE PONUMBER = @I_vDOCNUMBR)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 7(Purchase Order)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END 
IF @I_vME_Trx_Type = 8  -- Payroll Check
	BEGIN
		IF @I_vDOCTYPE <> 0  
			BEGIN
				SET @oErrString = 'DOCTYPE must be 0 for @I_vME_Trx_Type = 8(Payroll)'	
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		/*Validate should be against the employee table */
		IF @I_vME_Originating_Master_ID <> '' AND NOT EXISTS (SELECT * FROM UPR00100 /*UPR_MSTR*/ WHERE EMPLOYID = @I_vME_Originating_Master_ID)  
			BEGIN
				SET @oErrString = 'ME_Originating_Master_ID must a valid Employee(EMPLOYID) for @I_vME_Trx_Type = 8(Payroll)'
				SET @O_iErrorState = 65
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM UPR10302 /*UPR_TRX_Batch_Detail*/ WHERE COMPTRNM = @I_vDOCNUMBR)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 8(Payroll)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END 
IF @I_vME_Trx_Type = 9  -- Cash Receipt
	BEGIN
		IF @I_vDOCTYPE <> 9  --'RM Document Type-All' of table RM_Cash_WORK
			BEGIN
				SET @oErrString = 'DOCTYPE must be 9 for @I_vME_Trx_Type = 9(Cash Receipt)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vME_Originating_Master_ID <> '' AND NOT EXISTS (SELECT * FROM RM00101 /*RM_Customer_MSTR*/ WHERE CUSTNMBR = @I_vME_Originating_Master_ID)  
			BEGIN
				SET @oErrString = 'ME_Originating_Master_ID must a valid Customer(CUSTNMBR) for @I_vME_Trx_Type = 9(Cash Receipt)'
				SET @O_iErrorState = 65
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM RM10201 /*RM_Cash_WORK*/ WHERE DOCNUMBR = @I_vDOCNUMBR AND RMDTYPAL = @I_vDOCTYPE)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 9(Cash Receipt)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END 
IF @I_vME_Trx_Type = 10  -- Purchase Order Receipt
	BEGIN
		IF @I_vDOCTYPE <> 1 and @I_vDOCTYPE <> 3  --'POP Type' 
			BEGIN
				SET @oErrString = 'DOCTYPE must be 1 or 3 for @I_vME_Trx_Type = 10(PO Receipt)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vME_Originating_Master_ID <> '' AND NOT EXISTS (SELECT * FROM PM00200 /*PM_Vendor_MSTR*/ WHERE VENDORID = @I_vME_Originating_Master_ID)  
			BEGIN
				SET @oErrString = 'ME_Originating_Master_ID must a valid Vendor(VENDORID) for @I_vME_Trx_Type = 10(PO Receipt)'
				SET @O_iErrorState = 65
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM POP10300 /*POP_Receipt*/ WHERE POPRCTNM = @I_vDOCNUMBR)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 10(PO Receipt)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END
IF @I_vME_Trx_Type = 11  -- Inventory Adjustment
	BEGIN
		IF @I_vDOCTYPE NOT BETWEEN 1 AND 2  --'IV Document Type' of table IV_TRX_WORK_HDR
			BEGIN
				SET @oErrString = 'DOCTYPE must be either 1 and 2 for @I_vME_Trx_Type = 11(Inventory)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vME_Originating_Master_ID <> ''  
			BEGIN
				SET @oErrString = 'ME_Originating_Master_ID must be blank for @I_vME_Trx_Type = 11(Inventory)'
				SET @O_iErrorState = 65
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM IV10000 /*IV_TRX_WORK_HDR*/ WHERE IVDOCNBR = @I_vDOCNUMBR AND IVDOCTYP = @I_vDOCTYPE)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 11(Inventory)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END 
IF @I_vME_Trx_Type = 12  -- Bank Rec. Transaction
	BEGIN
		IF @I_vDOCTYPE <> 0  
			BEGIN
				SET @oErrString = 'DOCTYPE must be 0 for @I_vME_Trx_Type = 12(Bank Rec Transaction)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END
IF @I_vME_Trx_Type = 13 -- Purchase Order Invoice
	BEGIN
		IF @I_vDOCTYPE <> 2   --'POP Type' ...POP_DOCTYPE_INVOICE(2)
			BEGIN
				SET @oErrString = 'DOCTYPE must be 2 for @I_vME_Trx_Type = 13(PO Invoice)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vME_Originating_Master_ID <> '' AND NOT EXISTS (SELECT * FROM PM00200 /*PM_Vendor_MSTR*/ WHERE VENDORID = @I_vME_Originating_Master_ID)  
			BEGIN
				SET @oErrString = 'ME_Originating_Master_ID must a valid Vendor(VENDORID) for @I_vME_Trx_Type = 13(PO Invoice)'
				SET @O_iErrorState = 65
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM POP10300 /*POP_Receipt*/ WHERE POPRCTNM = @I_vDOCNUMBR)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 13(PO Invoice)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END 
IF @I_vME_Trx_Type = 14  -- Time Entry, NOT supported by PT at this time
	BEGIN
		IF @I_vDOCTYPE <> 0  
			BEGIN
				SET @oErrString = 'DOCTYPE must be 0 for @I_vME_Trx_Type = 14(Time Entry)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END
IF @I_vME_Trx_Type = 15  -- Contract Bill
	BEGIN
		IF @I_vDOCTYPE <> 0  
			BEGIN
				SET @oErrString = 'DOCTYPE must be 0 for @I_vME_Trx_Type = 15(RCB)'
				SET @O_iErrorState = 64
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vME_Originating_Master_ID <> '' AND NOT EXISTS (SELECT * FROM RM00101 /*RM_Customer_MSTR*/ WHERE CUSTNMBR = @I_vME_Originating_Master_ID)  
			BEGIN
				SET @oErrString = 'ME_Originating_Master_ID must a valid Customer(CUSTNMBR) for @I_vME_Trx_Type = 15(RCB)'
				SET @O_iErrorState = 65
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
		IF @I_vDOCDATE = '01/01/1900' AND NOT EXISTS (SELECT * FROM ME50405 /*RCB*/ WHERE ME_Contract_Number = @I_vDOCNUMBR)  
			BEGIN
				SET @oErrString = 'DOCDATE must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 15(RCB)'
				SET @O_iErrorState = 66
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END 


/*	@I_vME_Amount_Type:  one of the valid ones?
	1 = SALES
	2 = TRADE DISCOUNT
	3 = FREIGHT
	4 = MISC. CHARGE
	5 = SALES TAX
	6 = EST. COST LABOR
	7 = EST. COST MATERIAL
	8 = ACTUAL COST LABOR
	9 = ACTUAL COST MATERIAL
	10 = ADJUST
	11 = CASH    */
IF @I_vME_Amount_Type < 0 OR @I_vME_Amount_Type > 11   /*If ME_Amount_Type = 0, then we will default it*/
	BEGIN
		SET @O_iErrorState = 70
		SET @oErrString = 'ME_Amount_Type must be between 1 and 11'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
 
	
/*@I_vACTINDX:  DOES the Account exists in the GL_Account_Index_MSTR (GL00100) */
IF @I_vACTINDX <> 0 AND NOT EXISTS (SELECT * FROM GL00100 WHERE ACTINDX = @I_vACTINDX) 
	BEGIN
		SET @O_iErrorState = 71
		SET @oErrString = 'Account Index ' + CAST(@I_vACTINDX AS varchar(5)) + ' is not matched to an Account'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
IF @I_vACTINDX = 0  and @I_vME_Trx_Type <> 11  /*For Inventory transactions we will figure out the Acct */
	BEGIN
		SET @O_iErrorState = 72
		SET @oErrString = 'Account Index must be specified'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 


/*@I_vVOIDED: Voided flag must only be true or false */
IF @I_vVOIDED <> 0 AND @I_vVOIDED <> 1 
	BEGIN
		SET @O_iErrorState = 73
		SET @oErrString = 'VOIDED must be either 0(False) or 1(True)'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 


/*@I_vME_Job_Status: Job status is either 1=Open or 2=Completed 
  If 0, we will actually defaults it 1  */
IF @I_vME_Job_Status <> 0 AND @I_vME_Job_Status <> 1 AND @I_vME_Job_Status <> 2 
	BEGIN
		SET @O_iErrorState = 74
		SET @oErrString = 'ME_Job_Status must be either 1(Open) or 2(Completed)'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 

/*@I_vTRXAMNT amounts can't both be zero 
  however we will allow it for inventoried transactions*/
IF @I_vTRXAMNT = 0 AND @I_vORIGAMT = 0 AND @I_vME_Trx_Type <> 11 
	BEGIN
		SET @O_iErrorState = 75
		SET @oErrString = 'Transaction Amounts(@I_vTRXAMNT and @I_vORIGAMT) can not be zero'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 


/*User Defined field Validation: @I_vME_User_Defined (yes, weird field names)
	@I_vME_User_Defined, @I_vMEuserdefined1, @I_vMEuserdefined2, @I_vMEuserdefined3,
	@I_vME_User_Defined_5,  @I_vME_User_Defined_6, @I_vME_User_Defined_7 */
/* ME_User_Defined_1_Maint */
IF @I_vME_User_Defined <> '' AND NOT EXISTS (SELECT * FROM ME97701 WHERE ME_User_Defined = @I_vME_User_Defined) 
	BEGIN
		SET @O_iErrorState = 80
		SET @oErrString = 'User Defined 1(@I_vME_User_Defined) ' + RTRIM(@I_vME_User_Defined) + ' was not found in the ME97701 table'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_2_Maint */
IF @I_vMEuserdefined2 <> '' AND NOT EXISTS (SELECT * FROM ME97703 WHERE MEuserdefined2 = @I_vMEuserdefined2) 
	BEGIN
		SET @O_iErrorState = 81
		SET @oErrString = 'User Defined 2(@I_vMEuserdefined2) ' + RTRIM(@I_vMEuserdefined2) + ' was not found in the ME97703 table'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_3_Maint */
IF @I_vMEuserdefined3 <> '' AND NOT EXISTS (SELECT * FROM ME97702 WHERE MEuserdefined3 = @I_vMEuserdefined3) 
	BEGIN
		SET @O_iErrorState = 82
		SET @oErrString = 'User Defined 3(@I_vMEuserdefined3) ' + RTRIM(@I_vMEuserdefined3) + ' was not found in the ME97702 table'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_4_Maint */
IF @I_vMEuserdefined1 <> '' AND NOT EXISTS (SELECT * FROM ME97709 WHERE MEuserdefined1 = @I_vMEuserdefined1) 
	BEGIN
		SET @O_iErrorState = 83
		SET @oErrString = 'User Defined 4(@I_vMEuserdefined1) ' + RTRIM(@I_vME_User_Defined) + ' was not found in the ME97709 table'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_5_Maint */
IF @I_vME_User_Defined_5 <> '' AND NOT EXISTS (SELECT * FROM ME97717 WHERE ME_User_Defined_5 = @I_vME_User_Defined_5) 
	BEGIN
		SET @O_iErrorState = 84
		SET @oErrString = 'User Defined 5(@I_vME_User_Defined_5) ' + RTRIM(@I_vME_User_Defined_5) + ' was not found in the ME97717 table'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_6_Maint */
IF @I_vME_User_Defined_6 <> '' AND NOT EXISTS (SELECT * FROM ME97715 WHERE ME_User_Defined_6 = @I_vME_User_Defined_6) 
	BEGIN
		SET @O_iErrorState = 85
		SET @oErrString = 'User Defined 6(@I_vME_User_Defined_6) ' + RTRIM(@I_vME_User_Defined_6) + ' was not found in the ME97715 table'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_7_Maint */
IF @I_vME_User_Defined_7 <> '' AND NOT EXISTS (SELECT * FROM ME97716 WHERE ME_User_Defined_7 = @I_vME_User_Defined_7) 
	BEGIN
		SET @O_iErrorState = 86
		SET @oErrString = 'User Defined 7(@I_vME_User_Defined_7) ' + RTRIM(@I_vME_User_Defined_7) + ' was not found in the ME97716 table'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 


/*ORIGPONUMBER: validate the PO Number */
IF @I_vME_Trx_Type = 7 /* Purchase Order */ 
OR @I_vME_Trx_Type = 10 /* Purchase Order Receipt */
OR @I_vME_Trx_Type = 13 /* Purchase Order Invoice */
	BEGIN
		IF @I_vORIGPONUMBER <> '' AND NOT EXISTS (SELECT * FROM POP10100 WHERE PONUMBER = @I_vORIGPONUMBER) 
							   AND NOT EXISTS (SELECT * FROM POP30100 WHERE PONUMBER = @I_vORIGPONUMBER) 
			BEGIN
				SET @O_iErrorState = 90
				SET @oErrString = 'PO Number ' + RTRIM(@I_vORIGPONUMBER) + ' does not exist'
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END 
ELSE
	IF @I_vORIGPONUMBER <> ''
			BEGIN
				SET @O_iErrorState = 91
				SET @oErrString = 'The @I_vORIGPONUMBER should only be set for PO type of transactions'
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 


/*@@DSCRPTN & @I_vDSCRPTN255:  Description validation	*/
if SUBSTRING(@I_vDSCRIPTN,1,30) <> SUBSTRING(@I_vDSCRPTN255,1,30) 
	BEGIN
		/*defaults done in another routine
		IF  @I_vDSCRIPTN = ''   SET @I_vDSCRIPTN = SUBSTRING(@I_vDSCRPTN255,1,30) 
		IF  @I_vDSCRPTN255 = '' SET @I_vDSCRPTN255 = @I_vDSCRIPTN*/
		IF SUBSTRING(@I_vDSCRIPTN,1,30) <> SUBSTRING(@I_vDSCRPTN255,1,30) 
			BEGIN
				SET @O_iErrorState = 92
				SET @oErrString = 'The @I_vDSCRIPTN and @I_vDSCRPTN255 must be the same for the first 30 characters'
				SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END 
	END 

/*@@I_vHOURSWKD:  used only on payroll transactions	*/
IF @I_vHOURSWKD <> 0 AND @I_vME_Trx_Type <> 8  /* Payroll Check */
	BEGIN
		SET @O_iErrorState = 93
		SET @oErrString = '@I_vHOURSWKD is only used for payroll transactions'
		SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
	

/* Check to see if the Dynamics Transaction exists for the Work table transaction */
/*Not sure if we can/want this validation. The document may not be inserted yet. 
 This is just a warning.
 Only do this check if there are NO errors.*/
SET @oErrStringTemp = ''
IF @I_vDOCNUMBR <> '' AND @I_vDOCTYPE <> '' AND @O_iErrorState = 0
	BEGIN
	IF @I_vME_Trx_Type = 1  -- AP Voucher
		BEGIN
			IF NOT EXISTS 
				(SELECT VCHRNMBR FROM PM10000 /*PM_Transaction_WORK*/ WHERE VCHRNMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE  
					union all
				 SELECT VCHRNMBR FROM PM20000 /*PM_Transaction_OPEN*/ WHERE VCHRNMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE) 

				SET @oErrStringTemp = 'WARNING: DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 1(AP Voucher)'
		END 
	IF @I_vME_Trx_Type = 2  -- AR Invoice
		BEGIN
			IF NOT EXISTS (SELECT * FROM RM00401 /*RM_Keys_MSTR*/ WHERE DOCNUMBR = @I_vDOCNUMBR AND RMDTYPAL = @I_vDOCTYPE)  
				SET @oErrStringTemp = 'WARNING: DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 2(AR Invoice)'
		END 
	IF @I_vME_Trx_Type = 3  -- Invoicing Invoice
		BEGIN
			IF NOT EXISTS (SELECT * FROM IVC10100 /*IVC_HDR_WORK*/ WHERE INVCNMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE)  
				SET @oErrStringTemp = 'WARNING: DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 3(Invoicing Invoice)'
		END 
	IF @I_vME_Trx_Type = 4  -- GL Adjustment
		BEGIN
			IF NOT EXISTS (SELECT * FROM GL10000 /*GL_TRX_HDR_WORK*/ WHERE JRNENTRY = case when ISNUMERIC(@I_vDOCNUMBR) = 1 then @I_vDOCNUMBR else 0 end) 
				SET @oErrStringTemp = 'WARNING: DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 4(GL Adjustment)'
		END 	
	/*IF @I_vME_Trx_Type = 5  -- Project Tracking Adjustments
		IF @I_vDOCTYPE <> 0  
			SET @oErrString = 'DOCTYPE must be 0 for @I_vME_Trx_Type = 5 (Project Tracking Adjustments).'*/
	IF @I_vME_Trx_Type = 6  -- Sales Order
		BEGIN
			IF NOT EXISTS (SELECT * FROM SOP10100 /*SOP_HDR_WORK*/ WHERE SOPNUMBE = @I_vDOCNUMBR AND SOPTYPE = @I_vDOCTYPE)  
				SET @oErrStringTemp = 'WARNING: DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 6(Sales Order)'
		END 
	IF @I_vME_Trx_Type = 7  -- Purchase Order
		BEGIN
			IF NOT EXISTS (SELECT * FROM POP10100 /*POP_PO*/ WHERE PONUMBER = @I_vDOCNUMBR)  
				SET @oErrStringTemp = 'LNITMSEQ must be provided when the DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 7(Purchase Order)'
		END 
	IF @I_vME_Trx_Type = 8  -- Payroll Check
		BEGIN
			IF NOT EXISTS (SELECT * FROM UPR10302 /*UPR_TRX_Batch_Detail*/ WHERE COMPTRNM = @I_vDOCNUMBR)  
				SET @oErrStringTemp = 'WARNING: DOCNUMBER document doesnt exist:: @I_vME_Trx_Type = 8(Payroll)'
		END 
	IF @I_vME_Trx_Type = 9  -- Cash Receipt
		BEGIN
			IF NOT EXISTS (SELECT * FROM RM10201 /*RM_Cash_WORK*/ WHERE DOCNUMBR = @I_vDOCNUMBR AND RMDTYPAL = @I_vDOCTYPE)  
				SET @oErrStringTemp = 'WARNING: DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 9(Cash Receipt)'
		END 
	IF @I_vME_Trx_Type = 10  -- Purchase Order Receipt
		BEGIN
			IF NOT EXISTS (SELECT * FROM POP10300 /*POP_Receipt*/ WHERE POPRCTNM = @I_vDOCNUMBR)  
				SET @oErrStringTemp = 'WARNING: DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 10(PO Receipt)'
		END
	IF @I_vME_Trx_Type = 11  -- Inventory Adjustment
		BEGIN
			IF NOT EXISTS (SELECT * FROM IV10000 /*IV_TRX_WORK_HDR*/ WHERE IVDOCNBR = @I_vDOCNUMBR AND IVDOCTYP = @I_vDOCTYPE)  
				SET @oErrStringTemp = 'WARNING: DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 11(Inventory)'
		END 
	/*No validation for Bank Rec Transactions
	IF @I_vME_Trx_Type = 12  -- Bank Rec. Transaction
	*/	
	IF @I_vME_Trx_Type = 13 -- Purchase Order Invoice
		BEGIN
			IF NOT EXISTS (SELECT * FROM POP10300 /*POP_Receipt*/ WHERE POPRCTNM = @I_vDOCNUMBR)  
				SET @oErrStringTemp = 'WARNING: DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 13(PO Invoice)'
		END 
	/*Time Entry, NOT supported by PT at this time
	IF @I_vME_Trx_Type = 14  -- 	*/
	IF @I_vME_Trx_Type = 15  -- Contract Bill
		BEGIN
			IF NOT EXISTS (SELECT * FROM ME50405 /*RCB*/ WHERE ME_Contract_Number = @I_vDOCNUMBR)  
				SET @oErrStringTemp = 'WARNING: DOCNUMBER document doesnt exist: @I_vME_Trx_Type = 15(RCB)'
		END 
	IF @oErrStringTemp <> ''  --If any error identified above, then return error 
		BEGIN
			SET @oErrString = @oErrStringTemp
			SET @O_iErrorState = 10
			SET @oErrStringAll = @oErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
		END 
	END

GO




IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[EBS_PT_ValidateInsert_ME97705]') AND type in (N'P', N'PC'))
DROP PROCEDURE [dbo].[EBS_PT_ValidateInsert_ME97705]
GO


CREATE PROCEDURE [dbo].[EBS_PT_ValidateInsert_ME97705] --ME_Job_Cost_TRX_WORK
 
	@O_iErrorState			int				OUT,
	@oErrString				varchar(255)	OUT,
	@oErrStringAll			varchar(255)	OUT, 
	
	@I_vME_Job_ID			varchar(15)		= '',
	@I_vME_Trx_Type			int				= 0,
	@I_vDistType			int				= 0,
	@I_vLNITMSEQ			int				= 0,
	@I_vSQNCLINE			numeric(19, 5)	= 0,
	@I_vDOCDATE				datetime		= '01/01/1900',
	@I_vGLPOSTDT			datetime		= '01/01/1900',
	
	@I_vACTINDX					int				= 0,
	@I_vDOCNUMBR				varchar(21)		= '', 
	@I_vDOCTYPE					int				= 0,
	@I_vME_GL_Distribution_LI_In	int				= 0,
	@I_vME_Module_LI_Index			int				= 0,
	@I_vME_Document_Number_WORK		varchar(17)		= '', 
	
	@I_vDSCRIPTN					varchar(31)		= '', 
	@I_vDSCRPTN255					varchar(255)	= '', 

	@I_vTRXAMNT						numeric(19, 5)	= 0,
	@I_vORIGAMT						numeric(19, 5)	= 0,
	@I_vME_Breakdown_Code			varchar(15)		= '', 
	@I_vME_Amount_Type				int				= 0,
	@I_vME_Originating_Master_ID	varchar(31)		= '', 
	@I_vME_Originating_Mstr_Name	varchar(65)		= '', 
	@I_vJRNENTRY					int				= 0,
	
	@I_vME_User_Defined		varchar(15)		= '', 
	@I_vMEuserdefined1		varchar(15)		= '',  
	@I_vMEuserdefined2		varchar(15)		= '', 
	@I_vMEuserdefined3		varchar(15)		= '', 
	@I_vME_User_Defined_5	varchar(15)		= '', 
	@I_vME_User_Defined_6	varchar(15)		= '', 
	@I_vME_User_Defined_7	varchar(15)		= '', 

	@I_vME_Work_Order_Number		varchar(21)		= '', 
	@I_vME_Proposal_Number			varchar(15)		= '', 
	@I_vUnits						numeric(19, 5)	= 0,

	@I_vCOMMNTID					varchar(15)		= '', 
	@I_vHOURSWKD					int				= 0,
	@I_vORIGPONUMBER				varchar(17)		= '', 	
	@I_vVOIDED						int				= 0,
	@I_vME_Job_Status				int				= 0,
	@I_vGRANTID						varchar(15)		= '',
	@I_vUpdateIfExists				int				= 0,
	/*Can specify the Account either as the Account Index @I_vACTINDX or Account Number @I_vGLAcctString*/
	@I_vGLAcctString				varchar(50)		= ''
AS

DECLARE
	@oErrStringTemp	varchar(255),
	@my_ITEMNMBR	varchar(50),
/*Added by IBG 07/24/2017*/
	@BACHNUMB varchar(15),
	@BACHFREQ  int


SET NOCOUNT ON


/*Added Set Account Index based on Acct String Variable by IBG - 07/24/2017*/
If Coalesce(@I_vACTINDX, '') = ''
Set @I_vACTINDX = COALESCE((Select ACTINDX FROM GL00105 WHERE RTRIM(ACTNUMST) = @I_vGLAcctString),0)



EXEC dbo.[EBS_PT_VALIDATE_ME97705] 	
	@O_iErrorState OUTPUT, @oErrString OUTPUT, @oErrStringAll OUTPUT,
	
	@I_vME_Job_ID, @I_vME_Trx_Type,  @I_vDistType, @I_vLNITMSEQ, @I_vSQNCLINE, @I_vDOCDATE, @I_vGLPOSTDT,
	@I_vACTINDX, @I_vDOCNUMBR, @I_vDOCTYPE, @I_vME_GL_Distribution_LI_In, @I_vME_Module_LI_Index, @I_vME_Work_Order_Number, 
	@I_vDSCRIPTN, @I_vDSCRPTN255,
	@I_vTRXAMNT,  @I_vORIGAMT, @I_vME_Breakdown_Code, @I_vME_Amount_Type, @I_vME_Originating_Master_ID, @I_vME_Originating_Mstr_Name, @I_vJRNENTRY,
	@I_vME_User_Defined, @I_vMEuserdefined1, @I_vMEuserdefined2, @I_vMEuserdefined3, @I_vME_User_Defined_5, @I_vME_User_Defined_6, @I_vME_User_Defined_7, 
	@I_vME_Document_Number_WORK,  @I_vME_Proposal_Number, 
	@I_vCOMMNTID, @I_vHOURSWKD, @I_vORIGPONUMBER,@I_vVOIDED, @I_vME_Job_Status, @I_vGRANTID


IF @O_iErrorState = 0 /*IF no validation errors then we can proceed to find default values*/
	BEGIN
		/*@ME_GL_Distribution_LI and @I_vME_Module_LI_Indexs Defaults: this is the link back to the GP distributio lines for the GP document*/	
		IF @I_vME_Trx_Type = 1  -- AP Voucher
			BEGIN
				/*IF @I_vME_GL_Distribution_LI_In = 0   
					SELECT @I_vME_GL_Distribution_LI_In = COALESCE(MAX(DSTSQNUM),0) FROM PM10100 /*PM_Distribution_WORK_OPEN*/ where VCHRNMBR = @I_vDOCNUMBR AND DSTINDX = @I_vACTINDX
				SET @I_vME_Module_LI_Index = 0  /* No error message, we will just reset to zero  */  */
				IF @I_vME_GL_Distribution_LI_In = 0   
				  BEGIN
					IF @I_vDistType <> 0   
					--@I_vDistType (FOR AP) = CASH=1; PAY=2; AVAIL=3; TAKEN=4; FNCHG=5; PURCH=6; TRADE=7; MISC=8; FREIGHT=9; TAXES=10; WRITE=11; WRITE=12; ETC
					  BEGIN
						SELECT @I_vME_GL_Distribution_LI_In = 
							COALESCE(MAX(DSTSQNUM),0) 
							FROM PM10100 /*PM_Distribution_WORK_OPEN*/ 
							where VCHRNMBR = @I_vDOCNUMBR AND DSTINDX = @I_vACTINDX  and DISTTYPE = @I_vDistType AND (DEBITAMT - CRDTAMNT) = @I_vTRXAMNT
					
						IF @I_vME_GL_Distribution_LI_In = 0   
							SELECT @I_vME_GL_Distribution_LI_In = 
								COALESCE(MAX(DSTSQNUM),0) 
								FROM PM10100 /*PM_Distribution_WORK_OPEN*/ 
								where VCHRNMBR = @I_vDOCNUMBR AND DSTINDX = @I_vACTINDX  and DISTTYPE = @I_vDistType
					  END


					ELSE
					  BEGIN
						SELECT @I_vME_GL_Distribution_LI_In = 
							COALESCE(MAX(DSTSQNUM),0) 
							FROM PM10100 /*PM_Distribution_WORK_OPEN*/ 
							where VCHRNMBR = @I_vDOCNUMBR AND DSTINDX = @I_vACTINDX and (DEBITAMT - CRDTAMNT) = @I_vTRXAMNT
					
						IF @I_vME_GL_Distribution_LI_In = 0   
							SELECT @I_vME_GL_Distribution_LI_In = 
								COALESCE(MAX(DSTSQNUM),0) 
								FROM PM10100 /*PM_Distribution_WORK_OPEN*/ 
								where VCHRNMBR = @I_vDOCNUMBR AND DSTINDX = @I_vACTINDX 
						END
					END
				SET @I_vME_Module_LI_Index = 0  /* No error message, we will just reset to zero  */  
			END 
		IF @I_vME_Trx_Type = 2  -- AR Invoice
			BEGIN
				IF @I_vME_GL_Distribution_LI_In = 0   
					SELECT @I_vME_GL_Distribution_LI_In = COALESCE(MAX(SEQNUMBR),0) FROM RM10101 /*RM_Distribution_WORK*/  where DOCNUMBR = @I_vDOCNUMBR AND DSTINDX = @I_vACTINDX
				SET @I_vME_Module_LI_Index = 0  /* No error message, we will just reset to zero  */  
			END 
		IF @I_vME_Trx_Type = 3  -- Invoicing Invoice
			BEGIN
				IF @I_vME_GL_Distribution_LI_In = 0   
					SELECT @I_vME_GL_Distribution_LI_In = COALESCE(MAX(SEQNUMBR),0) FROM IVC10300 /*IVC_Distribution*/ where INVCNMBR = @I_vDOCNUMBR AND ACTINDX = @I_vACTINDX
				IF @I_vME_GL_Distribution_LI_In = 0  /*This generally will not happen but it could for Cost of Sales lines disbritubtion lines*/
					SELECT @I_vME_Module_LI_Index = (COALESCE(MAX(ME_Module_LI_Index),0) + 16384) FROM ME97705 WHERE ME_GL_Distribution_LI_In = 0 AND DOCNUMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE 
			END 
		IF @I_vME_Trx_Type = 4  -- GL Adjustment
			BEGIN
				SET @I_vME_GL_Distribution_LI_In = 0   
				SET @I_vME_Module_LI_Index = 0  
			END 
		/* PT Adjustments - not available for work transactions */
		IF @I_vME_Trx_Type = 5  -- Project Tracking Adjustments
			BEGIN
				SET @I_vME_GL_Distribution_LI_In = 0   
				SET @I_vME_Module_LI_Index = 0  
			END 
		IF @I_vME_Trx_Type = 6  -- Sales Order
			BEGIN
				IF @I_vME_GL_Distribution_LI_In = 0   
					SELECT @I_vME_GL_Distribution_LI_In = COALESCE(MAX(SEQNUMBR),0) FROM SOP10102 /*SOP_Distribution_WORK_HIST*/ where SOPNUMBE = @I_vDOCNUMBR AND SOPTYPE = @I_vDOCTYPE AND ACTINDX = @I_vACTINDX
				IF @I_vME_GL_Distribution_LI_In = 0  /*This generally will not happen but it could for Cost of Sales lines disbritubtion lines*/
					SELECT @I_vME_Module_LI_Index = (COALESCE(MAX(ME_Module_LI_Index),0) + 16384) FROM ME97705 WHERE ME_GL_Distribution_LI_In = 0 AND DOCNUMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE 
			END 
		IF @I_vME_Trx_Type = 7  -- Purchase Order
			BEGIN
				SET @I_vME_GL_Distribution_LI_In = 0   
				/*I don't like this one... We could return the wrong row IF THE SAME item has been distributed to more than one item */
				SELECT @I_vME_Module_LI_Index = COALESCE(MAX(ORD),0) FROM POP10110 /*POP_POLine*/ WHERE PONUMBER = @I_vDOCNUMBR AND ITEMDESC LIKE '%'+@I_vDSCRIPTN+'%' AND INVINDX = @I_vACTINDX
				/*I don't like this one... We could return the wrong row IF THE SAME index is used for more than one item */
				IF @I_vME_Module_LI_Index = 0 
					SELECT @I_vME_Module_LI_Index = COALESCE(MAX(ORD),0) FROM POP10110 /*POP_POLine*/ WHERE PONUMBER = @I_vDOCNUMBR AND INVINDX = @I_vACTINDX
			END 
		IF @I_vME_Trx_Type = 8  -- Payroll Check
			BEGIN
				SET @I_vME_GL_Distribution_LI_In = 0   
				SET @I_vME_Module_LI_Index = 0  
			END 
		IF @I_vME_Trx_Type = 9  -- Cash Receipt
			BEGIN
				IF @I_vME_GL_Distribution_LI_In = 0   
					SELECT @I_vME_GL_Distribution_LI_In = COALESCE(MAX(SEQNUMBR),0) FROM RM10101 /*RM_Distribution_WORK*/  where DOCNUMBR = @I_vDOCNUMBR AND DSTINDX = @I_vACTINDX
				SET @I_vME_Module_LI_Index = 0  /* No error message, we will just reset to zero  */  
			END 
		IF @I_vME_Trx_Type = 10  -- Purchase Order Receipt
			BEGIN
				IF @I_vME_GL_Distribution_LI_In = 0   
					SELECT @I_vME_GL_Distribution_LI_In = COALESCE(MAX(SEQNUMBR),0) FROM POP10390 /*POP_Distribution*/ WHERE POPRCTNM = @I_vDOCNUMBR AND ACTINDX = @I_vACTINDX
				IF @I_vME_Module_LI_Index = 0 
					SELECT @I_vME_Module_LI_Index = COALESCE(MAX(RCPTLNNM),0) FROM POP10500 /*POP_PORcptApply*/ WHERE POPRCTNM = @I_vDOCNUMBR AND INVINDX = @I_vACTINDX
			END
		IF @I_vME_Trx_Type = 11  -- Inventory Adjustment
			BEGIN

				/*CHANGES - OCT 29, 2015 
				IF @I_vME_Module_LI_Index = 0   
					SELECT @I_vME_Module_LI_Index = COALESCE(MAX(LNSEQNBR),0) FROM IV10001 /*IV_TRX_WORK_LINE*/ WHERE IVDOCNBR = @I_vDOCNUMBR AND IVIVOFIX = @I_vACTINDX
				*/
				IF @I_vACTINDX = 0   
					SELECT @I_vACTINDX = IVIVOFIX FROM IV10001 /*IV_TRX_WORK_LINE*/ WHERE IVDOCNBR = @I_vDOCNUMBR AND LNSEQNBR = @I_vME_Module_LI_Index

				IF @I_vTRXAMNT = 0 AND @I_vORIGAMT = 0  
					SELECT @I_vTRXAMNT = -EXTDCOST FROM IV10001 /*IV_TRX_WORK_LINE*/ WHERE IVDOCNBR = @I_vDOCNUMBR AND LNSEQNBR = @I_vME_Module_LI_Index

				IF  @I_vDSCRPTN255 = '' 
				  BEGIN 
					SELECT @I_vDSCRPTN255 = LTRIM(RTRIM(STR(-TRXQTY))) FROM IV10001 /*IV_TRX_WORK_LINE*/ WHERE IVDOCNBR = @I_vDOCNUMBR AND LNSEQNBR = @I_vME_Module_LI_Index
					SELECT @my_ITEMNMBR = ITEMNMBR FROM IV10001 /*IV_TRX_WORK_LINE*/ WHERE IVDOCNBR = @I_vDOCNUMBR AND LNSEQNBR = @I_vME_Module_LI_Index
					SELECT @I_vDSCRPTN255 = '(' + @I_vDSCRPTN255 + ') ' + MAX(ITEMDESC) FROM IV00101 WHERE ITEMNMBR = @my_ITEMNMBR
					SELECT @I_vDSCRIPTN  = @I_vDSCRPTN255
				  END
				 
				 IF @I_vUnits = 0 
					BEGIN
						SELECT @I_vUnits = -TRXQTY FROM IV10001 /*IV_TRX_WORK_LINE*/ WHERE IVDOCNBR = @I_vDOCNUMBR AND LNSEQNBR = @I_vME_Module_LI_Index
					END 
				 
				/*END CHANGES - OCT 29, 2015 */
			END 
		/*IF @I_vME_Trx_Type = 12  -- Bank Rec. Transaction
		*/
		IF @I_vME_Trx_Type = 13 -- Purchase Order Invoice
			BEGIN
				IF @I_vME_GL_Distribution_LI_In = 0   
					SELECT @I_vME_GL_Distribution_LI_In = COALESCE(MAX(SEQNUMBR),0) FROM POP10390 /*POP_Distribution*/ WHERE POPRCTNM = @I_vDOCNUMBR AND ACTINDX = @I_vACTINDX
				IF @I_vME_Module_LI_Index = 0 
					SELECT @I_vME_Module_LI_Index = COALESCE(MAX(RCPTLNNM),0) FROM POP10500 /*POP_PORcptApply*/ WHERE POPRCTNM = @I_vDOCNUMBR AND INVINDX = @I_vACTINDX
			END 
		/*IF @I_vME_Trx_Type = 14  -- Time Entry, NOT supported by PT at this time
		*/
		IF @I_vME_Trx_Type = 15  -- Contract Bill
			BEGIN
				SET @I_vME_GL_Distribution_LI_In = 0  /* No error message, we will just reset to zero  */  
				IF @I_vME_Module_LI_Index = 0   
					SELECT @I_vME_Module_LI_Index = COALESCE(MAX(LNITMSEQ),0) FROM ME50403 /*CONTRACT LINE*/ WHERE ME_Contract_Number = @I_vDOCNUMBR AND ACTINDX = @I_vACTINDX
			END 


		/*Doc Date default from original document when it is available*/
		IF @I_vDOCDATE = '01/01/1900'
		BEGIN
			IF @I_vME_Trx_Type = 1  -- AP Voucher
				BEGIN
					IF EXISTS(SELECT * FROM PM10000 /*PM_Transaction_WORK*/ WHERE VCHRNMBR = @I_vDOCNUMBR)
						SELECT @I_vDOCDATE = DOCDATE FROM PM10000 /*PM_Transaction_WORK*/ WHERE VCHRNMBR = @I_vDOCNUMBR  
					IF @I_vDOCDATE = '01/01/1900' AND EXISTS(SELECT * FROM PM20000 /*PM_Transaction_OPEN*/ WHERE VCHRNMBR = @I_vDOCNUMBR)
						SELECT @I_vDOCDATE = DOCDATE FROM PM20000 /*PM_Transaction_OPEN*/ WHERE VCHRNMBR = @I_vDOCNUMBR  
				END 
			IF @I_vME_Trx_Type = 2  -- AR Invoice
				BEGIN
					IF EXISTS(SELECT * FROM RM00401 /*RM_Keys_MSTR*/ WHERE DOCNUMBR = @I_vDOCNUMBR)
						SELECT @I_vDOCDATE = DOCDATE FROM RM00401 /*RM_Keys_MSTR*/ WHERE DOCNUMBR = @I_vDOCNUMBR  
				END 
			IF @I_vME_Trx_Type = 3  -- Invoicing Invoice
				BEGIN
					IF EXISTS (SELECT * FROM IVC10100 /*IVC_HDR_WORK*/ WHERE INVCNMBR = @I_vDOCNUMBR)  
						SELECT @I_vDOCDATE = DOCDATE FROM IVC10100 /*IVC_HDR_WORK*/ WHERE INVCNMBR = @I_vDOCNUMBR  
				END 
			IF @I_vME_Trx_Type = 4  -- GL Adjustment
				BEGIN
					IF EXISTS (SELECT * FROM GL10000 /*GL_TRX_HDR_WORK*/ WHERE JRNENTRY = case when ISNUMERIC(@I_vDOCNUMBR) = 1 then @I_vDOCNUMBR else 0 end)  
						SELECT @I_vDOCDATE = TRXDATE FROM GL10000 /*GL_TRX_HDR_WORK*/ WHERE JRNENTRY = case when ISNUMERIC(@I_vDOCNUMBR) = 1 then @I_vDOCNUMBR else 0 end 
				END 				
			/* not allowed for work transactions
			IF @I_vME_Trx_Type = 5  -- Project Tracking Adjustments			*/
			IF @I_vME_Trx_Type = 6  -- Sales Order
				BEGIN
					IF EXISTS (SELECT * FROM SOP10100 /*SOP_HDR_WORK*/ WHERE SOPNUMBE = @I_vDOCNUMBR)  
						SELECT @I_vDOCDATE = DOCDATE FROM SOP10100 /*SOP_HDR_WORK*/ WHERE SOPNUMBE = @I_vDOCNUMBR  
				END 
			IF @I_vME_Trx_Type = 7  -- Purchase Order
				BEGIN
					IF EXISTS (SELECT * FROM POP10100 /*POP_PO*/ WHERE PONUMBER = @I_vDOCNUMBR)  
						SELECT @I_vDOCDATE = DOCDATE FROM POP10100 /*POP_PO*/ WHERE PONUMBER = @I_vDOCNUMBR  
				END 
			IF @I_vME_Trx_Type = 8  -- Payroll Check
				BEGIN
					IF EXISTS (SELECT * FROM UPR10302 /*UPR_TRX_Batch_Detail*/ WHERE COMPTRNM = @I_vDOCNUMBR)  
						SELECT @I_vDOCDATE = TRXBEGDT FROM UPR10302 /*UPR_TRX_Batch_Detail*/ WHERE COMPTRNM = @I_vDOCNUMBR  
				END 
			IF @I_vME_Trx_Type = 9  -- Cash Receipt
				BEGIN
					IF EXISTS (SELECT * FROM RM10201 /*RM_Cash_WORK*/ WHERE DOCNUMBR = @I_vDOCNUMBR)  
						SELECT @I_vDOCDATE = DOCDATE FROM RM10201 /*RM_Cash_WORK*/ WHERE DOCNUMBR = @I_vDOCNUMBR  
				END 
			IF @I_vME_Trx_Type = 10  -- Purchase Order Receipt
				BEGIN
					IF EXISTS (SELECT * FROM POP10300 /*POP_Receipt*/ WHERE POPRCTNM = @I_vDOCNUMBR)  
						SELECT @I_vDOCDATE = receiptdate FROM POP10300 /*POP_Receipt*/ WHERE POPRCTNM = @I_vDOCNUMBR 
				END
			IF @I_vME_Trx_Type = 11  -- Inventory Adjustment
				BEGIN
					IF EXISTS (SELECT * FROM IV10000 /*IV_TRX_WORK_HDR*/ WHERE IVDOCNBR = @I_vDOCNUMBR)  
						SELECT @I_vDOCDATE = DOCDATE FROM IV10000 /*IV_TRX_WORK_HDR*/ WHERE IVDOCNBR = @I_vDOCNUMBR  
				END 
			/*IF @I_vME_Trx_Type = 12  -- Bank Rec. Transaction
			*/
			IF @I_vME_Trx_Type = 13 -- Purchase Order Invoice
				BEGIN
					IF EXISTS (SELECT * FROM POP10300 /*POP_Receipt*/ WHERE POPRCTNM = @I_vDOCNUMBR)  
						SELECT @I_vDOCDATE = receiptdate FROM POP10300 /*POP_Receipt*/ WHERE POPRCTNM = @I_vDOCNUMBR 
				END 
			/*IF @I_vME_Trx_Type = 14  -- Time Entry, NOT supported by PT at this time
			*/
			IF @I_vME_Trx_Type = 15  -- Contract Bill
				BEGIN
					IF EXISTS (SELECT * FROM ME50405 /*RCB*/ WHERE ME_Contract_Number = @I_vDOCNUMBR)  
						SELECT @I_vDOCDATE = MEBillingStartDate FROM ME50405 /*RCB*/ WHERE ME_Contract_Number = @I_vDOCNUMBR  
				END 
		END 


		/*MASTER IDs Defaults: ME_Originating_Master_ID, ME_Originating_Mstr_Name*/	
		IF @I_vME_Originating_Master_ID = '' OR @I_vME_Originating_Mstr_Name = ''
		BEGIN
			IF @I_vME_Trx_Type = 1  -- AP Voucher
				BEGIN
					IF @I_vME_Originating_Master_ID = '' 
						SELECT @I_vME_Originating_Master_ID = VENDORID FROM PM10000 /*PM_Transaction_WORK*/ WHERE VCHRNMBR = @I_vDOCNUMBR  
					IF @I_vME_Originating_Master_ID = '' 
						SELECT @I_vME_Originating_Master_ID = VENDORID FROM PM20000 /*PM_Transaction_OPEN*/ WHERE VCHRNMBR = @I_vDOCNUMBR  
					IF @I_vME_Originating_Mstr_Name = ''
						SELECT @I_vME_Originating_Mstr_Name = VENDNAME FROM PM00200 /*PM_Vendor_MSTR*/ WHERE VENDORID = @I_vME_Originating_Master_ID  
				END 
			IF @I_vME_Trx_Type = 2  -- AR Invoice
				BEGIN
					IF @I_vME_Originating_Master_ID = '' 
						SELECT @I_vME_Originating_Master_ID = CUSTNMBR FROM RM00401 /*RM_Keys_MSTR*/ WHERE DOCNUMBR = @I_vDOCNUMBR 
					IF @I_vME_Originating_Mstr_Name = ''
						SELECT @I_vME_Originating_Mstr_Name = CUSTNAME FROM RM00101 /*RM_Customer_MSTR*/ WHERE CUSTNMBR = @I_vME_Originating_Master_ID  
				END 
			IF @I_vME_Trx_Type = 3  -- Invoicing Invoice
				BEGIN
					IF @I_vME_Originating_Master_ID = '' 
						SELECT @I_vME_Originating_Master_ID = CUSTNMBR FROM IVC10100 /*IVC_HDR_WORK*/ WHERE INVCNMBR = @I_vDOCNUMBR 
					IF @I_vME_Originating_Mstr_Name = ''
						SELECT @I_vME_Originating_Mstr_Name = CUSTNAME FROM RM00101 /*RM_Customer_MSTR*/ WHERE CUSTNMBR = @I_vME_Originating_Master_ID  
				END 
			IF @I_vME_Trx_Type = 4  -- GL Adjustment
				BEGIN
					SET @I_vME_Originating_Master_ID = '' 
						SET @I_vME_Originating_Master_ID = CAST(@I_vACTINDX AS varchar(31))
					IF @I_vME_Originating_Mstr_Name = ''
						SELECT @I_vME_Originating_Mstr_Name = ACTDESCR FROM GL00100 /*GL_ACCT_MSTR*/ WHERE ACTINDX = @I_vME_Originating_Master_ID  
				END 
			/* PT Adjustments - the Master_ID must be fed in, but it isn't required
			IF @I_vME_Trx_Type = 5  -- Project Tracking Adjustments
			'*/
			IF @I_vME_Trx_Type = 6  -- Sales Order
				BEGIN
					IF @I_vME_Originating_Master_ID = '' 
						SELECT @I_vME_Originating_Master_ID = CUSTNMBR FROM SOP10100 /*SOP_HDR_WORK*/ WHERE SOPNUMBE = @I_vDOCNUMBR 
					IF @I_vME_Originating_Mstr_Name = ''
						SELECT @I_vME_Originating_Mstr_Name = CUSTNAME FROM RM00101 /*RM_Customer_MSTR*/ WHERE CUSTNMBR = @I_vME_Originating_Master_ID  
				END 
			IF @I_vME_Trx_Type = 7  -- Purchase Order
				BEGIN
					IF @I_vME_Originating_Master_ID = '' 
						SELECT @I_vME_Originating_Master_ID = VENDORID FROM POP10100 /*POP_PO*/ WHERE PONUMBER = @I_vDOCNUMBR  
					IF @I_vME_Originating_Mstr_Name = ''
						SELECT @I_vME_Originating_Mstr_Name = VENDNAME FROM PM00200 /*PM_Vendor_MSTR*/ WHERE VENDORID = @I_vME_Originating_Master_ID  
				END 
			IF @I_vME_Trx_Type = 8  -- Payroll Check
				BEGIN
					IF @I_vME_Originating_Master_ID = '' 
						SELECT @I_vME_Originating_Master_ID = EMPLOYID FROM UPR10302 /*UPR_TRX_Batch_Detail*/ WHERE COMPTRNM = @I_vDOCNUMBR  
					IF @I_vME_Originating_Mstr_Name = ''
						SELECT @I_vME_Originating_Mstr_Name = LASTNAME + ',' + FRSTNAME FROM UPR00100 /*UPR_MSTR*/ WHERE EMPLOYID = @I_vME_Originating_Master_ID  
				END 
			IF @I_vME_Trx_Type = 9  -- Cash Receipt
				BEGIN
					IF @I_vME_Originating_Master_ID = '' 
						SELECT @I_vME_Originating_Master_ID = CUSTNMBR FROM RM10201 /*RM_Cash_WORK*/ WHERE DOCNUMBR = @I_vDOCNUMBR 
					IF @I_vME_Originating_Mstr_Name = ''
						SELECT @I_vME_Originating_Mstr_Name = CUSTNAME FROM RM00101 /*RM_Customer_MSTR*/ WHERE CUSTNMBR = @I_vME_Originating_Master_ID  
				END 
			IF @I_vME_Trx_Type = 10  -- Purchase Order Receipt
				BEGIN
					IF @I_vME_Originating_Master_ID = '' 
						SELECT @I_vME_Originating_Master_ID = VENDORID FROM POP10300 /*POP_Receipt*/ WHERE POPRCTNM = @I_vDOCNUMBR  
					IF @I_vME_Originating_Mstr_Name = ''
						SELECT @I_vME_Originating_Mstr_Name = VENDNAME FROM PM00200 /*PM_Vendor_MSTR*/ WHERE VENDORID = @I_vME_Originating_Master_ID  
				END
			IF @I_vME_Trx_Type = 11  -- Inventory Adjustment
				BEGIN
					SET @I_vME_Originating_Master_ID = '' 
					SET @I_vME_Originating_Mstr_Name = '' 
				END 
			/*IF @I_vME_Trx_Type = 12  -- Bank Rec. Transaction
			*/
			IF @I_vME_Trx_Type = 13 -- Purchase Order Invoice
				BEGIN
					IF @I_vME_Originating_Master_ID = '' 
						SELECT @I_vME_Originating_Master_ID = VENDORID FROM POP10300 /*POP_Receipt*/ WHERE POPRCTNM = @I_vDOCNUMBR  
					IF @I_vME_Originating_Mstr_Name = ''
						SELECT @I_vME_Originating_Mstr_Name = VENDNAME FROM PM00200 /*PM_Vendor_MSTR*/ WHERE VENDORID = @I_vME_Originating_Master_ID  
				END 
			/*IF @I_vME_Trx_Type = 14  -- Time Entry, NOT supported by PT at this time
			*/
			IF @I_vME_Trx_Type = 15  -- Contract Bill
				BEGIN
					IF @I_vME_Originating_Master_ID = '' 
						SELECT @I_vME_Originating_Master_ID = CUSTNMBR FROM ME50405 /*RCB*/ WHERE ME_Contract_Number = @I_vDOCNUMBR 
					IF @I_vME_Originating_Mstr_Name = ''
						SELECT @I_vME_Originating_Mstr_Name = CUSTNAME FROM RM00101 /*RM_Customer_MSTR*/ WHERE CUSTNMBR = @I_vME_Originating_Master_ID  
				END 
		END 
			

		/*Job status can default to 1*/
		IF @I_vME_Job_Status = 0 SET @I_vME_Job_Status = 1

		/*Make the longer and shorter description fields the same */
		if SUBSTRING(@I_vDSCRIPTN,1,30) <> SUBSTRING(@I_vDSCRPTN255,1,30) 
			BEGIN
				IF  @I_vDSCRIPTN = ''   SET @I_vDSCRIPTN = SUBSTRING(@I_vDSCRPTN255,1,30) 
				IF  @I_vDSCRPTN255 = '' SET @I_vDSCRPTN255 = @I_vDSCRIPTN
			END 
			
		/*Default user defined fields from the Project */
		if @I_vME_User_Defined = '' AND @I_vMEuserdefined1 = '' AND @I_vMEuserdefined2 = '' AND @I_vMEuserdefined3 = ''
		AND @I_vME_User_Defined_5 = '' AND @I_vME_User_Defined_6 = '' AND @I_vME_User_Defined_7 = '' 
			BEGIN
				SELECT @I_vME_User_Defined = ME_User_Defined, 
						@I_vMEuserdefined1 = MEuserdefined1, 
						@I_vMEuserdefined2 = MEuserdefined2, 
						@I_vMEuserdefined3 = MEuserdefined3, 
						@I_vME_User_Defined_5 = ME_User_Defined_5, 
						@I_vME_User_Defined_6 = ME_User_Defined_6, 
						@I_vME_User_Defined_7 = ME_User_Defined_7 
				FROM ME97708
				WHERE ME_Job_ID = @I_vME_Job_ID
			END
		
			
		/*Default work order and proposal number from the Project */
		if @I_vME_Proposal_Number = ''  
			BEGIN
				SELECT @I_vME_Proposal_Number = ME_Proposal_Number
				FROM ME97708
				WHERE ME_Job_ID = @I_vME_Job_ID
			END
		if @I_vME_Work_Order_Number = ''  
			BEGIN
				SELECT @I_vME_Work_Order_Number = ME_Work_Order_Number
				FROM ME97708
				WHERE ME_Job_ID = @I_vME_Job_ID
			END	
		
		
		/*Default amount if only one is set */
		IF @I_vTRXAMNT = 0 AND @I_vORIGAMT <> 0 
			BEGIN
				SET @I_vTRXAMNT = @I_vORIGAMT
			END 
		IF @I_vTRXAMNT <> 0 AND @I_vORIGAMT = 0 
			BEGIN
				SET @I_vORIGAMT = @I_vTRXAMNT
			END 

		/*Default ME_Document_Number_WORK from DOCNUMBR */
		IF @I_vME_Document_Number_WORK = ''  
			SET @I_vME_Document_Number_WORK = @I_vDOCNUMBR
			
			
		/*Default JRNENTRY  */
		IF @I_vJRNENTRY = 0 AND @I_vME_Trx_Type = 4  /*-- GL Adjustment */
			SET @I_vJRNENTRY = case when ISNUMERIC(@I_vDOCNUMBR) = 1 then @I_vDOCNUMBR else 0 end
			
			
		/*Default GLPOSTDT  */
		IF @I_vGLPOSTDT = '01-01-1900' 
			SET @I_vGLPOSTDT = @I_vDOCDATE
			

		/*Default the Breakdown code - depends of the transaction type*/	
		IF @I_vME_Breakdown_Code = ''	
			BEGIN				
				IF @I_vME_Trx_Type = 1  -- AP Voucher
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_2
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 2  -- AR Invoice
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_3
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 3  -- Invoicing Invoice
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_4
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 4  -- GL Adjustment
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_1
						FROM ME97710		
				/*Defaults not allowed for PT Adjustments transactions
				IF @I_vME_Trx_Type = 5  -- Project Tracking Adjustments
				*/
				IF @I_vME_Trx_Type = 6  -- Sales Order
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_5
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 7  -- Purchase Order
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_6
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 8  -- Payroll Check
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_7
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 9  -- Cash Receipt
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_8
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 10  -- Purchase Order Receipt
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_6
						FROM ME97710
					END
				IF @I_vME_Trx_Type = 11  -- Inventory Adjustment
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_9
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 12  -- Bank Rec. Transaction
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_8
						FROM ME97710
				IF @I_vME_Trx_Type = 13 -- Purchase Order Invoice
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_6
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 14  -- Time Entry ....but shouldn't ever come here
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_1
						FROM ME97710
				IF @I_vME_Trx_Type = 15  -- Contract Bill...use SOP defaults
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Breakdowns_5
						FROM ME97710
					END 
			END	


	/*	@I_vME_Amount_Type:  
		1 = SALES
		2 = TRADE DISCOUNT
		3 = FREIGHT
		4 = MISC. CHARGE
		5 = SALES TAX
		6 = EST. COST LABOR
		7 = EST. COST MATERIAL
		8 = ACTUAL COST LABOR
		9 = ACTUAL COST MATERIAL
		10 = ADJUST
		11 = CASH    */
		/*Default the Amount Type - depends of the transaction type*/	
		IF @I_vME_Amount_Type = ''	
			BEGIN				
				IF @I_vME_Trx_Type = 1  -- AP Voucher
					BEGIN
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_2
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 2  -- AR Invoice
					BEGIN
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_3
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 3  -- Invoicing Invoice
					BEGIN
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_4
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 4  -- GL Adjustment
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_1
						FROM ME97710		
				IF @I_vME_Trx_Type = 5  -- Project Tracking Adjustments
					BEGIN
						SELECT @I_vME_Amount_Type = 1  /*use SALES */
					END 
				IF @I_vME_Trx_Type = 6  -- Sales Order
					BEGIN
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_5
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 7  -- Purchase Order
					BEGIN
						SELECT @I_vME_Breakdown_Code = ME_Default_Amount_Type_6
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 8  -- Payroll Check
					BEGIN
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_7
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 9  -- Cash Receipt
					BEGIN
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_8
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 10  -- Purchase Order Receipt
					BEGIN
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_6
						FROM ME97710
					END
				IF @I_vME_Trx_Type = 11  -- Inventory Adjustment
					BEGIN
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_9
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 12  -- Bank Rec. Transaction
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_8
						FROM ME97710
				IF @I_vME_Trx_Type = 13 -- Purchase Order Invoice
					BEGIN
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_6
						FROM ME97710
					END 
				IF @I_vME_Trx_Type = 14  -- Time Entry ....but shouldn't ever come here
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_1
						FROM ME97710
				IF @I_vME_Trx_Type = 15  -- Contract Bill...use SOP defaults
					BEGIN
						SELECT @I_vME_Amount_Type = ME_Default_Amount_Type_5  /*use SOP defaults*/
						FROM ME97710
					END 
			END	

			
		/*Override the breakdown defaulted from the setup (above code) 
			With any (may not be) breakdown assigned to the GL Account 
			fyi: Segments are not yet supported*/
		SELECT @I_vME_Breakdown_Code = ME_Breakdown_Code 
		FROM ME97757 
		WHERE ACTINDX = @I_vACTINDX 
				and ME_Amount_Type = @I_vME_Amount_Type 
				and ME_CB_Default_Breakdown = 1
				and GL_Option = 1
							

	/*LNITMSEQ can be defaulted in... next one PLUS 16384
	  SQNCLINE can be defaulted in???? next one PLUS 500 */
		IF @I_vME_Trx_Type = 4 
			BEGIN
				/*Sequence line is in mulitples of 500 */
				SELECT @I_vSQNCLINE = (COALESCE(MAX(SQNCLINE),0)+ 500) 
					FROM ME97705 
					WHERE DOCNUMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE AND ME_Amount_Type = @I_vME_Amount_Type
				SET @I_vLNITMSEQ = 16384
			END	
		IF @I_vME_Trx_Type <> 4 
			BEGIN 
				SET @I_vSQNCLINE = 0
				SELECT @I_vLNITMSEQ = (COALESCE(MAX(LNITMSEQ),0)+ 16384) 
					FROM ME97705 
					WHERE DOCNUMBR = @I_vDOCNUMBR AND DOCTYPE = @I_vDOCTYPE AND ME_Amount_Type = @I_vME_Amount_Type
			END 


	/*Actually insert the record into the ME97705 table*/
	INSERT ME97705 (ME_Job_ID, GRANTID, ME_Trx_Type, ME_Breakdown_Code, LNITMSEQ, SQNCLINE,
					DOCDATE, DOCNUMBR, ME_Document_Number_WORK, DOCTYPE, ME_Work_Order_Number,
					DSCRIPTN, ME_Amount_Type, TRXAMNT, ME_Originating_Master_ID, ME_Proposal_Number,
					JRNENTRY, ACTINDX, HOURSWKD, GLPOSTDT, ME_GL_Distribution_LI_In,
					ME_Module_LI_Index, ORIGAMT, COMMNTID, VOIDED, ME_Originating_Mstr_Name,
					DSCRPTN255, ORIGPONUMBER, ME_User_Defined, MEuserdefined1,
					MEuserdefined2, MEuserdefined3, ME_User_Defined_5, ME_User_Defined_6, ME_User_Defined_7)
	 VALUES (@I_vME_Job_ID, @I_vGRANTID, @I_vME_Trx_Type, @I_vME_Breakdown_Code, @I_vLNITMSEQ, @I_vSQNCLINE,
	 		@I_vDOCDATE, @I_vDOCNUMBR, @I_vME_Document_Number_WORK, @I_vDOCTYPE, @I_vME_Work_Order_Number,
	 		@I_vDSCRIPTN, @I_vME_Amount_Type, @I_vTRXAMNT, @I_vME_Originating_Master_ID, @I_vME_Proposal_Number,
	 		@I_vJRNENTRY, @I_vACTINDX, @I_vHOURSWKD, @I_vGLPOSTDT, @I_vME_GL_Distribution_LI_In,
	 		@I_vME_Module_LI_Index, @I_vORIGAMT, @I_vCOMMNTID, @I_vVOIDED, @I_vME_Originating_Mstr_Name, 
			@I_vDSCRPTN255, @I_vORIGPONUMBER, @I_vME_User_Defined, @I_vMEuserdefined1,
			@I_vMEuserdefined2, @I_vMEuserdefined3, @I_vME_User_Defined_5, @I_vME_User_Defined_6, @I_vME_User_Defined_7)

	/*Updating Project Costs*/
	IF @I_vME_Amount_Type = 8 /* [ME_AMTTYPE_ACTCOSTLABOR]*/
		UPDATE  ME97708 SET ME_Actual_Cost_Labor = ME_Actual_Cost_Labor + @I_vTRXAMNT WHERE ME_Job_ID = @I_vME_Job_ID
	ELSE IF @I_vME_Amount_Type = 9 /* [ME_AMTTYPE_ACTCOSTMATERIAL]*/
		UPDATE  ME97708 SET ME_Actual_Cost_Material = ME_Actual_Cost_Material + @I_vTRXAMNT WHERE ME_Job_ID = @I_vME_Job_ID
	ELSE IF @I_vME_Amount_Type = 10 /* [ME_AMTTYPE_ADJUST]*/
		UPDATE  ME97708 SET ME_Adjustments = ME_Adjustments + @I_vTRXAMNT WHERE ME_Job_ID = @I_vME_Job_ID
	ELSE IF @I_vME_Amount_Type = 6 /* [ME_AMTTYPE_ESTCOSTLABOR]*/
		UPDATE  ME97708 SET ME_Est_Cost_Labor = ME_Est_Cost_Labor + @I_vTRXAMNT WHERE ME_Job_ID = @I_vME_Job_ID
	ELSE IF @I_vME_Amount_Type = 7 /* [ME_AMTTYPE_ESTCOSTMATERIAL]*/
		UPDATE  ME97708 SET ME_Est_Cost_Material = ME_Est_Cost_Material + @I_vTRXAMNT WHERE ME_Job_ID = @I_vME_Job_ID
	ELSE IF @I_vME_Amount_Type = 3 /* [ME_AMTTYPE_FREIGHT]*/
		UPDATE  ME97708 SET FRTAMNT = FRTAMNT + @I_vTRXAMNT WHERE ME_Job_ID = @I_vME_Job_ID
	ELSE IF @I_vME_Amount_Type = 4 /*[ME_AMTTYPE_MISCCHARGE]*/
		UPDATE  ME97708 SET MISCAMNT = MISCAMNT + @I_vTRXAMNT WHERE ME_Job_ID = @I_vME_Job_ID
	ELSE IF @I_vME_Amount_Type = 1 /*[ME_AMTTYPE_SALES]*/
		UPDATE  ME97708 SET ME_Actual_Operating_Reve = ME_Actual_Operating_Reve + @I_vTRXAMNT WHERE ME_Job_ID = @I_vME_Job_ID
	ELSE IF @I_vME_Amount_Type = 5 /*[ME_AMTTYPE_SALESTAX]*/
		UPDATE  ME97708 SET ME_Actual_Sales_Tax = ME_Actual_Sales_Tax + @I_vTRXAMNT WHERE ME_Job_ID = @I_vME_Job_ID
	ELSE IF @I_vME_Amount_Type = 2 /*[ME_AMTTYPE_TRADEDISC]*/
		UPDATE  ME97708 SET TRDISAMT = TRDISAMT + @I_vTRXAMNT WHERE ME_Job_ID = @I_vME_Job_ID
	ELSE IF @I_vME_Amount_Type = 11 /*[ME_AMTTYPE_CASH]*/
		UPDATE  ME97708 SET ME_Actual_Rev_Collected = ME_Actual_Rev_Collected + @I_vTRXAMNT WHERE ME_Job_ID = @I_vME_Job_ID
	
		

	/***************Added by IBG 07/24/2017*/
		IF @I_vME_Trx_Type = 4  -- GL Adjustment
			BEGIN
				Set @BACHNUMB = (SELECT Distinct BACHNUMB FROM GL10000 /*GL_TRX_HDR_WORK*/ WHERE JRNENTRY = case when ISNUMERIC(@I_vDOCNUMBR) = 1 then @I_vDOCNUMBR else 0 end)  
				/*setting the ME_Is_Recurring_JE*/
				Set @BACHFREQ = (Select Case when BACHFREQ > 1 then 1 else 0 end from SY00500 where BACHNUMB = @BACHNUMB)

				INSERT ME97749  /*ME_GL_TRX_HDR_WORK_Cache - 
					This table is really only needed for recurring batches (when ME_Is_Recurring_JE > 0)*/
						(BACHNUMB,BCHSOURC,JRNENTRY,RCTRXSEQ,SOURCDOC,REFRENCE,TRXDATE,RVRSNGDT,RCRNGTRX,BALFRCLC,
						PSTGSTUS,LASTUSER,LSTDTEDT,USWHPSTD,TRXTYPE,SQNCLINE,GLHDRMSG,GLHDRMS2,TRXSORCE,RVTRXSRC,
						SERIES,ORPSTDDT,ORTRXSRC,OrigDTASeries,DTAControlNum,DTATRXType,DTA_Index,CURNCYID,CURRNIDX,
						RATETPID,EXGTBLID,XCHGRATE,EXCHDATE,TIME1,RTCLCMTD,NOTEINDX,GLHDRVAL,PERIODID,OPENYEAR,
						CLOSEDYR,HISTRX,REVPRDID,REVYEAR,REVCLYR,REVHIST,ERRSTATE,ICTRX,ORCOMID,ORIGINJE,ICDISTS,
						PRNTSTUS,DENXRATE,MCTRXSTT,DOCDATE,Tax_Date,VOIDED,Original_JE,Original_JE_Year,
						Original_JE_Seq_Num,Correcting_Trx_Type,ME_Is_Recurring_JE)
      
				Select
					   A.BACHNUMB,A.BCHSOURC,A.JRNENTRY,A.RCTRXSEQ,A.SOURCDOC,A.REFRENCE,A.TRXDATE,A.RVRSNGDT,A.RCRNGTRX,A.BALFRCLC,
					   A.PSTGSTUS,A.LASTUSER,A.LSTDTEDT,A.USWHPSTD,A.TRXTYPE,A.SQNCLINE,A.GLHDRMSG,A.GLHDRMS2,A.TRXSORCE,A.RVTRXSRC,
					   A.SERIES,A.ORPSTDDT,A.ORTRXSRC,A.OrigDTASeries,A.DTAControlNum,A.DTATRXType,A.DTA_Index,A.CURNCYID,A.CURRNIDX,
					   A.RATETPID,A.EXGTBLID,A.XCHGRATE,A.EXCHDATE,A.TIME1,A.RTCLCMTD,A.NOTEINDX,A.GLHDRVAL,A.PERIODID,A.OPENYEAR,
					   A.CLOSEDYR,A.HISTRX,A.REVPRDID,A.REVYEAR,A.REVCLYR,A.REVHIST,A.ERRSTATE,A.ICTRX,A.ORCOMID,A.ORIGINJE,A.ICDISTS,
					   A.PRNTSTUS,A.DENXRATE,A.MCTRXSTT,A.DOCDATE,A.Tax_Date,A.VOIDED,A.Original_JE,A.
					   Original_JE_Year,A.Original_JE_Seq_Num,A.Correcting_Trx_Type,@BACHFREQ
				From GL10000 A
				WHERE A.JRNENTRY NOT IN (SELECT JRNENTRY FROM ME97749)

			END 				
	/********************END IBG Addition*/

	END

GO



GRANT EXECUTE ON [dbo].[EBS_PT_ValidateInsert_ME97705] TO DYNGRP 
GRANT EXECUTE ON [dbo].[EBS_PT_VALIDATE_ME97705] TO DYNGRP 