/*************************************************************************************************************************
PROJECT:		Project Tracking
SCRIPT NAME:	EBS_PT_ValidateInsert_ME97708.sql
DESCRIPTION:	

	This script creates TWO stored procedures:
	
		[EBS_PT_ValidateInsert_ME97708]
		[EBS_PT_VALIDATE_ME97708]

	It is expected that customers will only call the [EBS_PT_ValidateInsert_ME97708] as it runs the [EBS_PT_VALIDATE_ME97708] 
	script which validates a potential insert into the Project Tracking tables below:
	
		ME97708 - ME_Job_Cost_OPEN
		ME97735 - ME_Project_User_Projects
			
	The script also runs a system stored procedure 'smGetNextNoteIndex' to get the next Note Index for the project so it is 
	necessary to supply the correct System Database as an input parameter.

	NOTE:
	There is a spreadsheet with helpful information for working with this script related to its error validations: 
		
		PT_ProjectValidationErrors.xlsx

	Due to the large number of parameters it is recommended that you explictly set the parameters you actually want to use.
	Let the script set the other fields to default values.

	Example:
	
		DECLARE @O_iErrorState		int				
		DECLARE	@oErrString			varchar(255)	
		DECLARE	@I_vErrStringAll	varchar(255)	

		EXEC dbo.[EBS_PT_ValidateInsert_ME97708] 
			@O_iErrorState OUT, 
			@oErrString OUT, 
			@I_vErrStringAll OUT,  
			@I_vME_Job_ID = 'GPUG', 
			@I_vUSERID = 'sa',
			@I_vSystemDatabase = 'DYN01'

		SELECT @O_iErrorState, @oErrString, @I_vErrStringAll

REQUIRED PARAMETERS:	

			@I_vME_Job_ID
			@I_vSystemDatabase
						
			IMPORTANT!: 
				The GP System Database is usually DYNAMICS or DYN01, if in case the database name is different, 
			user should modify this script to change all strings '[dbname]' and replace ALL with
			the correct system database name, else the script will not run and get an error like below:
				 
				Error:	'Invalid object name 'dbname..SY01400'
				
			WARNING Messages:
			
			Warning message like this can be ignored:
			
				Warning: "The module 'EBS_PT_ValidateInsert_ME97708' depends on the missing object 'dbname..smGetNextNoteIndex'. 
						 The module will still be created; however, it cannot run successfully until the object exists."
				
			This message shows up because the system database name needed to be updated as instructed above.

----------

CREATED BY		MODIFIED DATE		WHAT
KNN				01.20.2015			Initial Creation - Inserting new projects

************************************************************************************************************************/

/****** Object:  StoredProcedure [dbo].[EBS_PT_VALIDATE_ME97708]    Script Date: ******/

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

--ME_Job_Cost_OPEN
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[EBS_PT_VALIDATE_ME97708]') AND type in (N'P', N'PC'))
	DROP PROCEDURE [dbo].[EBS_PT_VALIDATE_ME97708]
GO

CREATE PROCEDURE [dbo].[EBS_PT_VALIDATE_ME97708] --ME_Job_Cost_OPEN

	@O_iErrorState					int				OUT,
	@oErrString						varchar(255)	OUT,
	@I_vErrStringAll				varchar(255)	OUT,
	
	@I_vME_Job_ID                    varchar(15)    = '',
	@I_vME_Description               varchar(41)	= '',
	
	@I_vME_Job_Open_Date             datetime		= '01-01-1900',
	@I_vME_Job_Close_Date            datetime		= '01-01-1900',
	@I_vME_Est_Start_Date            datetime		= '01-01-1900',
	@I_vME_Est_Complete_Date         datetime		= '01-01-1900',
	@I_vME_Actual_Start_Date         datetime		= '01-01-1900',
	@I_vME_Actual_End_Date           datetime		= '01-01-1900',
	
	@I_vME_Proposal_Number           varchar(15)    = '',	
	@I_vME_Work_Order_Number         varchar(21)    = '',
	@I_vME_Job_Status                int			= 0,
	
	@I_vCUSTNMBR                     varchar(15)    = '',
	@I_vSalesPersonID                varchar(15)    = '',	
	
	@I_vME_User_Defined_1            varchar(15)    = '',
	@I_vME_User_Defined_2            varchar(15)    = '',
	@I_vME_User_Defined_3            varchar(15)    = '',
	@I_vME_User_Defined_4            varchar(15)    = '',
	@I_vME_User_Defined_5            varchar(15)    = '',
	@I_vME_User_Defined_6            varchar(15)    = '',
	@I_vME_User_Defined_7            varchar(15)    = '',
	
	@I_vME_Used_In_Budgeting_1       int			= 0,
	@I_vME_Used_In_Budgeting_2       int			= 0,
	@I_vME_Used_In_Budgeting_3       int			= 0,
	@I_vME_Used_In_Budgeting_4       int			= 0,
	@I_vME_Used_In_Budgeting_5       int			= 0,
	@I_vME_Used_In_Budgeting_6       int			= 0,
	@I_vME_Used_In_Budgeting_7       int			= 0,
	
	@I_vME_User_Defined_Constant_1   int			= 0,
	@I_vME_User_Defined_Constant_2   int			= 0,
	@I_vME_User_Defined_Constant_3   int			= 0,
	@I_vME_User_Defined_Constant_4   int			= 0,
	@I_vME_User_Defined_Constant_5   int			= 0,
	@I_vME_User_Defined_Constant_6   int			= 0,
	@I_vME_User_Defined_Constant_7   int			= 0,
	
	@I_vME_Exclude_From_Reports      int			= 0,
	
	@I_vME_Est_Operating_Revenue     numeric(19, 5)	= 0,
	@I_vME_Actual_Operating_Reve     numeric(19, 5)	= 0,
	@I_vME_Actual_Sales_Tax          numeric(19, 5)	= 0,
	@I_vME_Est_Cost_Labor            numeric(19, 5)	= 0,
	@I_vME_Est_Cost_Material         numeric(19, 5)	= 0,
	@I_vME_Orig_Est_Cost_Labo        numeric(19, 5) = 0,
	@I_vME_Orig_Est_Cost_Mate        numeric(19, 5) = 0,
	@I_vME_Actual_Cost_Labor         numeric(19, 5) = 0,
	@I_vME_Actual_Cost_Material      numeric(19, 5) = 0,
	@I_vFRTAMNT                      numeric(19, 5) = 0,
	@I_vMISCAMNT                     numeric(19, 5) = 0,
	@I_vTRDISAMT                     numeric(19, 5) = 0,
	@I_vNOTEINDX                     numeric(19, 5) = 0,
	@I_vME_Op_Cost__Revenue          numeric(19, 5) = 0,
	@I_vME_Op_Cost__CostLabor        numeric(19, 5) = 0,
	@I_vME_Op_Cost__Cost_Materie     numeric(19, 5) = 0,
	@I_vME_Adjustments               numeric(19, 5) = 0,
	@I_vME_Actual_Rev_Collected      numeric(19, 5)	= 0,
	@I_vME_WIP_Account_Ind           int			= 0,
	@I_vME_CB_Udefs_1                int			= 0,
	@I_vME_CB_Udefs_2                int			= 0,
	@I_vME_CB_Udefs_3                int			= 0,
	@I_vME_CB_Udefs_4                int			= 0,
	@I_vME_CB_Udefs_5                int			= 0,
	@I_vME_CB_Udefs_6                int			= 0,
	@I_vME_CB_Udefs_7                int			= 0,
	@I_vME_Date_Udefs_1              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_2              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_3              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_4              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_5              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_6              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_7              datetime		= '01-01-1900',
	@I_vME_Numeric_Udefs_1           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_2           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_3           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_4           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_5           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_6           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_7           numeric(19, 5)	= 0,
	@I_vDEFAULTGRANTID               varchar(15)    = '',
	
	@I_vUSERID						 varchar(15)    = '',
	@I_vME_View_Status				 int			= 0,
	@I_vME_EditStatus				 int			= 0,
	@I_vME_DistributionStatus		 int			= 0,
	@I_vME_Budget_Approve_Status	 int			= 0,
	@I_vME_Budget_Edit_Status		 int			= 0,
	@I_vME_Budget_Reopen_Status		 int			= 0,
	@I_vME_Budget_View_Status		 int			= 0,
	@I_vME_AdjustStatus				 int			= 0,
	@I_vME_UserWhoEdited			 varchar(15)    = '',
	@I_vUSERDATE					 datetime		= '01-01-1900',
	
	@I_vSystemDatabase				 varchar(15)    = '',
	@O_vCompanyID					 varchar(15)	= '',
	@O_mNoteIndex					 NUMERIC(19, 5) = 0,
	@O_iNoteErrorState				 int			= 0,
	@DBNAME							 sysname		= ''
AS

DECLARE
	@oErrStringTemp	varchar(255)

SET NOCOUNT ON
SET @O_iErrorState = 0
SET @oErrString = 'No Errors'
SET @I_vErrStringAll = ''

/*Error Validations*/

/*@I_vSystemDatabase - Validate System Database*/
IF RTRIM(@I_vSystemDatabase) = ''
	BEGIN
		SET @O_iErrorState = 50
		SET @oErrString = 'System Database: @I_vSystemDatabase is required.'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END

/*@I_vUSERID: Requires valid GP user ID to be able to insert project security setup*/
/*@DBNAME - Validate GP Database Name*/

SELECT @DBNAME = DB_NAME()

IF RTRIM(@I_vSystemDatabase) = 'DYN01'
	BEGIN
		/*Set @O_vCompanyID*/
		
		IF RTRIM(@I_vUSERID) <> '' AND NOT EXISTS (SELECT * FROM DYN01..SY01400 WHERE USERID = @I_vUSERID)
			BEGIN
				SET @O_iErrorState = 51
				SET @oErrString = 'USERID: User ID ' + '"' + RTRIM(@I_vUSERID) + '"' + ' is invalid in ' + @I_vSystemDatabase
				SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END
				
		IF @DBNAME <> '' AND NOT EXISTS (SELECT CMPANYID FROM DYN01..SY01500 WHERE INTERID = @DBNAME)
			BEGIN
				SET @O_iErrorState = 52
				SET @oErrString = '@DBNAME: Database Name ' + '"' + RTRIM(@DBNAME) + '"' + ' does not exist in Company Master.'
				SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END		
	END
		
IF RTRIM(@I_vSystemDatabase) = 'DYNAMICS'
	BEGIN
		IF RTRIM(@I_vUSERID) <> '' AND NOT EXISTS (SELECT * FROM DYNAMICS..SY01400 WHERE USERID = @I_vUSERID)
			BEGIN
				SET @O_iErrorState = 51
				SET @oErrString = 'USERID: User ID ' + '"' + RTRIM(@I_vUSERID) + '"' + ' is invalid in ' + @I_vSystemDatabase
				SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END
		
		IF @DBNAME <> '' AND NOT EXISTS (SELECT CMPANYID FROM DYNAMICS..SY01500 WHERE INTERID = @DBNAME)
			BEGIN
				SET @O_iErrorState = 52
				SET @oErrString = '@DBNAME: Database Name ' + '"' + RTRIM(@DBNAME) + '"' + ' does not exist in Company Master.'
				SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END
	END	

/*CUSTOM SYSTEM DATABASE - Need to specify system database where table SY01400 and SY01500 are located*/
/*Change '[dbname]' in the queries below, system database is usually DYN01 or DYNAMICS but indicate correct as appropriate*/
IF RTRIM(@I_vSystemDatabase) NOT IN ('DYN01', 'DYNAMICS')
	BEGIN
		IF RTRIM(@I_vUSERID) <> '' AND NOT EXISTS (SELECT * FROM [dbname]..SY01400 WHERE USERID = @I_vUSERID)
			BEGIN
				SET @O_iErrorState = 51
				SET @oErrString = 'USERID: User ID ' + '"' + RTRIM(@I_vUSERID) + '"' + ' is invalid in ' + @I_vSystemDatabase
				SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END	
		
		IF @DBNAME <> '' AND NOT EXISTS (SELECT * FROM [dbname]..SY01500 WHERE INTERID = @DBNAME)
			BEGIN
				SET @O_iErrorState = 52
				SET @oErrString = '@DBNAME: Database Name ' + '"' + RTRIM(@DBNAME) + '"' + ' does not exist in Company Master.'
				SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
			END
	END

/*@I_vME_Job_ID:  JOB ID is required field*/
IF @I_vME_Job_ID = ''
	BEGIN
		SET @O_iErrorState = 53
		SET @oErrString = 'Job ID: @I_vME_Job_ID is required.'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END

/*@I_vME_Job_ID:  Does the project already exist in the ME_Job_Cost_OPEN */
IF @I_vME_Job_ID <> '' AND EXISTS (SELECT * FROM ME97708 WHERE ME_Job_ID = @I_vME_Job_ID) 
	BEGIN
		SET @O_iErrorState = 54
		SET @oErrString = 'ME_Job_ID: Project ' + RTRIM(@I_vME_Job_ID) + ' already exists.'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END

/*@I_vME_Job_Status: Job status is either 1=Open or 2=Completed 
  If 0, we will actually default to 1  */
IF @I_vME_Job_Status <> 0 AND @I_vME_Job_Status <> 1 AND @I_vME_Job_Status <> 2 
	BEGIN
		SET @O_iErrorState = 55
		SET @oErrString = 'ME_Job_Status must be either 1(Open) or 2(Completed)'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END

/*@I_vCUSTNMBR: Does Customer Number exist*/
IF @I_vCUSTNMBR <> '' AND NOT EXISTS (SELECT * FROM RM00101 WHERE RTRIM(CUSTNMBR) = RTRIM(UPPER(@I_vCUSTNMBR)))
	BEGIN
		SET @O_iErrorState = 56
		SET @oErrString = 'Customer ID ' + UPPER(RTRIM(@I_vCUSTNMBR)) + ' does not exist'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END

/*@I_vSalesPersonID: Does Sales Person exist*/	
IF @I_vSalesPersonID <> '' AND NOT EXISTS (SELECT * FROM RM00301 WHERE RTRIM(SLPRSNID) = RTRIM(UPPER(@I_vSalesPersonID)))
	BEGIN
		SET @O_iErrorState = 57
		SET @oErrString = 'Salesperson ' + UPPER(RTRIM(@I_vSalesPersonID)) + ' does not exist'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END


/*User Defined field Validation: @I_vME_User_Defined_1, @I_vME_User_Defined_2, @I_vME_User_Defined_3, @I_vME_User_Defined_4
	@I_vME_User_Defined_5,  @I_vME_User_Defined_6, @I_vME_User_Defined_7 */
/* ME_User_Defined_1_Maint */
IF @I_vME_User_Defined_1 <> '' AND NOT EXISTS (SELECT * FROM ME97701 WHERE RTRIM(ME_User_Defined) = RTRIM(UPPER(@I_vME_User_Defined_1))) 
	BEGIN
		SET @O_iErrorState = 80
		SET @oErrString = 'User Defined 1(@I_vME_User_Defined_1) ' + RTRIM(UPPER(@I_vME_User_Defined_1)) + ' was not found in the ME97701 table'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_2_Maint */
IF @I_vME_User_Defined_2 <> '' AND NOT EXISTS (SELECT * FROM ME97703 WHERE RTRIM(MEuserdefined2) = RTRIM(UPPER(@I_vME_User_Defined_2))) 
	BEGIN
		SET @O_iErrorState = 81
		SET @oErrString = 'User Defined 2(@I_vME_User_Defined_2) ' + RTRIM(@I_vME_User_Defined_2) + ' was not found in the ME97703 table'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_3_Maint */
IF @I_vME_User_Defined_3 <> '' AND NOT EXISTS (SELECT * FROM ME97702 WHERE RTRIM(MEuserdefined3) = RTRIM(UPPER(@I_vME_User_Defined_3))) 
	BEGIN
		SET @O_iErrorState = 82
		SET @oErrString = 'User Defined 3(@I_vME_User_Defined_3) ' + RTRIM(@I_vME_User_Defined_3) + ' was not found in the ME97702 table'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_4_Maint */
IF @I_vME_User_Defined_4 <> '' AND NOT EXISTS (SELECT * FROM ME97709 WHERE RTRIM(MEuserdefined1) = RTRIM(UPPER(@I_vME_User_Defined_4))) 
	BEGIN
		SET @O_iErrorState = 83
		SET @oErrString = 'User Defined 4(@I_vME_User_Defined_4) ' + RTRIM(@I_vME_User_Defined_4) + ' was not found in the ME97709 table'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_5_Maint */
IF @I_vME_User_Defined_5 <> '' AND NOT EXISTS (SELECT * FROM ME97717 WHERE RTRIM(ME_User_Defined_5) = RTRIM(UPPER(@I_vME_User_Defined_5))) 
	BEGIN
		SET @O_iErrorState = 84
		SET @oErrString = 'User Defined 5(@I_vME_User_Defined_5) ' + RTRIM(@I_vME_User_Defined_5) + ' was not found in the ME97717 table'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_6_Maint */
IF @I_vME_User_Defined_6 <> '' AND NOT EXISTS (SELECT * FROM ME97715 WHERE RTRIM(ME_User_Defined_6) = RTRIM(UPPER(@I_vME_User_Defined_6))) 
	BEGIN
		SET @O_iErrorState = 85
		SET @oErrString = 'User Defined 6(@I_vME_User_Defined_6) ' + RTRIM(@I_vME_User_Defined_6) + ' was not found in the ME97715 table'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 
/* ME_User_Defined_7_Maint */
IF @I_vME_User_Defined_7 <> '' AND NOT EXISTS (SELECT * FROM ME97716 WHERE RTRIM(ME_User_Defined_7) = RTRIM(UPPER(@I_vME_User_Defined_7))) 
	BEGIN
		SET @O_iErrorState = 86
		SET @oErrString = 'User Defined 7(@I_vME_User_Defined_7) ' + RTRIM(@I_vME_User_Defined_7) + ' was not found in the ME97716 table'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 


/*Constant Values: Should only be marked if User defined fields exist*/
IF @I_vME_User_Defined_Constant_1 <> 0 AND RTRIM(@I_vME_User_Defined_1) = ''
	BEGIN
		SET @O_iErrorState = 90
		SET @oErrString = 'Must set User Defined 1 (@I_vME_User_Defined_1) before setting constant value (@I_vME_User_Defined_Constant_1)'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END
IF @I_vME_User_Defined_Constant_2 <> 0 AND RTRIM(@I_vME_User_Defined_2) = ''
	BEGIN
		SET @O_iErrorState = 91
		SET @oErrString = 'Must set User Defined 2 (@I_vME_User_Defined_2) before setting constant value (@I_vME_User_Defined_Constant_2)'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END
IF @I_vME_User_Defined_Constant_3 <> 0 AND RTRIM(@I_vME_User_Defined_3) = ''
	BEGIN
		SET @O_iErrorState = 92
		SET @oErrString = 'Must set User Defined 3 (@I_vME_User_Defined_3) before setting constant value (@I_vME_User_Defined_Constant_3)'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END
IF @I_vME_User_Defined_Constant_4 <> 0 AND RTRIM(@I_vME_User_Defined_4) = ''
	BEGIN
		SET @O_iErrorState = 93
		SET @oErrString = 'Must set User Defined 4 (@I_vME_User_Defined_4) before setting constant value (@I_vME_User_Defined_Constant_4)'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END
IF @I_vME_User_Defined_Constant_5 <> 0 AND RTRIM(@I_vME_User_Defined_5) = ''
	BEGIN
		SET @O_iErrorState = 94
		SET @oErrString = 'Must set User Defined 5 (@I_vME_User_Defined_5) before setting constant value (@I_vME_User_Defined_Constant_5)'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END
IF @I_vME_User_Defined_Constant_6 <> 0 AND RTRIM(@I_vME_User_Defined_6) = ''
	BEGIN
		SET @O_iErrorState = 95
		SET @oErrString = 'Must set User Defined 6 (@I_vME_User_Defined_6) before setting constant value (@I_vME_User_Defined_Constant_7)'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END
IF @I_vME_User_Defined_Constant_7 <> 0 AND RTRIM(@I_vME_User_Defined_7) = ''
	BEGIN
		SET @O_iErrorState = 96
		SET @oErrString = 'Must set User Defined 7 (@I_vME_User_Defined_7) before setting constant value (@I_vME_User_Defined_Budget_C_8)'
		SET @I_vErrStringAll = @I_vErrStringAll + CAST(@O_iErrorState AS varchar(3)) + ': ' + @oErrString + '; '
	END 

GO

------
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[EBS_PT_ValidateInsert_ME97708]') AND type in (N'P', N'PC'))
	DROP PROCEDURE [dbo].[EBS_PT_ValidateInsert_ME97708]
GO

CREATE PROCEDURE [dbo].[EBS_PT_ValidateInsert_ME97708] --ME_Job_Cost_OPEN
	@O_iErrorState					int						OUT,
	@oErrString						varchar(255)			OUT,
	@I_vErrStringAll				varchar(255)	= ''	OUT, 

	@I_vME_Job_ID                    varchar(15)    = '',
	@I_vME_Description               varchar(41)	= '',
	
	@I_vME_Job_Open_Date             datetime		= '01-01-1900',
	@I_vME_Job_Close_Date            datetime		= '01-01-1900',
	@I_vME_Est_Start_Date            datetime		= '01-01-1900',
	@I_vME_Est_Complete_Date         datetime		= '01-01-1900',
	@I_vME_Actual_Start_Date         datetime		= '01-01-1900',
	@I_vME_Actual_End_Date           datetime		= '01-01-1900',
	
	@I_vME_Proposal_Number           varchar(15)    = '',
	@I_vME_Work_Order_Number         varchar(21)    = '',
	@I_vME_Job_Status                int			= 0,
	
	@I_vCUSTNMBR                     varchar(15)    = '',
	@I_vSalesPersonID                varchar(15)    = '',
	
	@I_vME_User_Defined_1            varchar(15)    = '',
	@I_vME_User_Defined_2            varchar(15)    = '',
	@I_vME_User_Defined_3            varchar(15)    = '',
	@I_vME_User_Defined_4            varchar(15)    = '',
	@I_vME_User_Defined_5            varchar(15)    = '',
	@I_vME_User_Defined_6            varchar(15)    = '',
	@I_vME_User_Defined_7            varchar(15)    = '',
	
	@I_vME_Used_In_Budgeting_1       int			= 0,
	@I_vME_Used_In_Budgeting_2       int			= 0,
	@I_vME_Used_In_Budgeting_3       int			= 0,
	@I_vME_Used_In_Budgeting_4       int			= 0,
	@I_vME_Used_In_Budgeting_5       int			= 0,
	@I_vME_Used_In_Budgeting_6       int			= 0,
	@I_vME_Used_In_Budgeting_7       int			= 0,
	
	@I_vME_User_Defined_Constant_1   int			= 0,
	@I_vME_User_Defined_Constant_2   int			= 0,
	@I_vME_User_Defined_Constant_3   int			= 0,
	@I_vME_User_Defined_Constant_4   int			= 0,
	@I_vME_User_Defined_Constant_5   int			= 0,
	@I_vME_User_Defined_Constant_6   int			= 0,
	@I_vME_User_Defined_Constant_7   int			= 0,
	
	@I_vME_Exclude_From_Reports      int			= 0,
	
	@I_vME_Est_Operating_Revenue     numeric(19, 5)	= 0,		
	@I_vME_Actual_Operating_Reve     numeric(19, 5)	= 0,
	@I_vME_Actual_Sales_Tax          numeric(19, 5)	= 0,
	@I_vME_Est_Cost_Labor            numeric(19, 5)	= 0,
	@I_vME_Est_Cost_Material         numeric(19, 5)	= 0,
	@I_vME_Orig_Est_Cost_Labo        numeric(19, 5) = 0,
	@I_vME_Orig_Est_Cost_Mate        numeric(19, 5) = 0,
	@I_vME_Actual_Cost_Labor         numeric(19, 5) = 0,
	@I_vME_Actual_Cost_Material      numeric(19, 5) = 0,
	@I_vFRTAMNT                      numeric(19, 5) = 0,
	@I_vMISCAMNT                     numeric(19, 5) = 0,
	@I_vTRDISAMT                     numeric(19, 5) = 0,	
	@I_vNOTEINDX                     numeric(19, 5) = 0,
	@I_vME_Op_Cost__Revenue          numeric(19, 5) = 0,
	@I_vME_Op_Cost__CostLabor        numeric(19, 5) = 0,
	@I_vME_Op_Cost__Cost_Materie     numeric(19, 5) = 0,
	@I_vME_Adjustments               numeric(19, 5) = 0,	
	@I_vME_Actual_Rev_Collected      numeric(19, 5)	= 0,	
	@I_vME_WIP_Account_Ind           int			= 0,
	@I_vME_CB_Udefs_1                int			= 0,
	@I_vME_CB_Udefs_2                int			= 0,
	@I_vME_CB_Udefs_3                int			= 0,
	@I_vME_CB_Udefs_4                int			= 0,
	@I_vME_CB_Udefs_5                int			= 0,
	@I_vME_CB_Udefs_6                int			= 0,
	@I_vME_CB_Udefs_7                int			= 0,
	@I_vME_Date_Udefs_1              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_2              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_3              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_4              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_5              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_6              datetime		= '01-01-1900',
	@I_vME_Date_Udefs_7              datetime		= '01-01-1900',
	@I_vME_Numeric_Udefs_1           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_2           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_3           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_4           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_5           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_6           numeric(19, 5)	= 0,
	@I_vME_Numeric_Udefs_7           numeric(19, 5)	= 0,
	@I_vDEFAULTGRANTID               varchar(15)    = '',
	
	@I_vUSERID						 varchar(15)    = '',
	@I_vME_View_Status				 int			= 0,
	@I_vME_EditStatus				 int			= 0,
	@I_vME_DistributionStatus		 int			= 0,
	@I_vME_Budget_Approve_Status	 int			= 0,
	@I_vME_Budget_Edit_Status		 int			= 0,
	@I_vME_Budget_Reopen_Status		 int			= 0,
	@I_vME_Budget_View_Status		 int			= 0,
	@I_vME_AdjustStatus				 int			= 0,
	@I_vME_UserWhoEdited			 varchar(15)    = '',
	@I_vUSERDATE					 datetime		= '01-01-1900',
	
	@I_vSystemDatabase				 varchar(15)    = '',
	@O_vCompanyID					 varchar(15)	= '',
	@O_mNoteIndex					 NUMERIC(19, 5) = 0,
	@O_iNoteErrorState				 int			= 0,
	@DBNAME							 sysname		= ''
	
AS

DECLARE @oErrStringTemp	varchar(255)
	
SET NOCOUNT ON
	
EXEC dbo.[EBS_PT_VALIDATE_ME97708]	
	@O_iErrorState OUTPUT, 
	@oErrString OUTPUT, 
	@I_vErrStringAll OUTPUT,	
	
	@I_vME_Job_ID
	,@I_vME_Description            
	
	,@I_vME_Job_Open_Date          
	,@I_vME_Job_Close_Date         
	,@I_vME_Est_Start_Date         
	,@I_vME_Est_Complete_Date      
	,@I_vME_Actual_Start_Date      
	,@I_vME_Actual_End_Date        
	
	,@I_vME_Proposal_Number        
	,@I_vME_Work_Order_Number      
	,@I_vME_Job_Status             
	
	,@I_vCUSTNMBR                  
	,@I_vSalesPersonID                  
	
	,@I_vME_User_Defined_1         
	,@I_vME_User_Defined_2            	
	,@I_vME_User_Defined_3            
	,@I_vME_User_Defined_4            
	,@I_vME_User_Defined_5         
	,@I_vME_User_Defined_6         
	,@I_vME_User_Defined_7           
	
	,@I_vME_Used_In_Budgeting_1    
	,@I_vME_Used_In_Budgeting_2    
	,@I_vME_Used_In_Budgeting_3    
	,@I_vME_Used_In_Budgeting_4    
	,@I_vME_Used_In_Budgeting_5    
	,@I_vME_Used_In_Budgeting_6    
	,@I_vME_Used_In_Budgeting_7    
	
	,@I_vME_User_Defined_Constant_1
	,@I_vME_User_Defined_Constant_2
	,@I_vME_User_Defined_Constant_3
	,@I_vME_User_Defined_Constant_4
	,@I_vME_User_Defined_Constant_5
	,@I_vME_User_Defined_Constant_6
	,@I_vME_User_Defined_Constant_7
	
	,@I_vME_Exclude_From_Reports              

	,@I_vME_Est_Operating_Revenue                
	,@I_vME_Actual_Operating_Reve  
	,@I_vME_Actual_Sales_Tax       
	,@I_vME_Est_Cost_Labor         
	,@I_vME_Est_Cost_Material      
	,@I_vME_Orig_Est_Cost_Labo     
	,@I_vME_Orig_Est_Cost_Mate     
	,@I_vME_Actual_Cost_Labor      
	,@I_vME_Actual_Cost_Material   
	,@I_vFRTAMNT                   
	,@I_vMISCAMNT                  
	,@I_vTRDISAMT                  
	,@I_vNOTEINDX                  
	,@I_vME_Op_Cost__Revenue       
	,@I_vME_Op_Cost__CostLabor     
	,@I_vME_Op_Cost__Cost_Materie  
	,@I_vME_Adjustments            
	,@I_vME_Actual_Rev_Collected   
	
	,@I_vME_WIP_Account_Ind        
	,@I_vME_CB_Udefs_1             
	,@I_vME_CB_Udefs_2             
	,@I_vME_CB_Udefs_3             
	,@I_vME_CB_Udefs_4             
	,@I_vME_CB_Udefs_5             
	,@I_vME_CB_Udefs_6             
	,@I_vME_CB_Udefs_7             
	,@I_vME_Date_Udefs_1           
	,@I_vME_Date_Udefs_2           
	,@I_vME_Date_Udefs_3           
	,@I_vME_Date_Udefs_4           
	,@I_vME_Date_Udefs_5           
	,@I_vME_Date_Udefs_6           
	,@I_vME_Date_Udefs_7           
	,@I_vME_Numeric_Udefs_1        
	,@I_vME_Numeric_Udefs_2        
	,@I_vME_Numeric_Udefs_3        
	,@I_vME_Numeric_Udefs_4        
	,@I_vME_Numeric_Udefs_5        
	,@I_vME_Numeric_Udefs_6        
	,@I_vME_Numeric_Udefs_7        
	,@I_vDEFAULTGRANTID
	,@I_vUSERID
	,@I_vME_View_Status
	,@I_vME_EditStatus
	,@I_vME_DistributionStatus
	,@I_vME_Budget_Approve_Status
	,@I_vME_Budget_Edit_Status
	,@I_vME_Budget_Reopen_Status
	,@I_vME_Budget_View_Status
	,@I_vME_AdjustStatus
	,@I_vME_UserWhoEdited
	,@I_vUSERDATE
	,@I_vSystemDatabase
	,@O_vCompanyID
	,@O_mNoteIndex					 
	,@O_iNoteErrorState				 
	,@DBNAME

IF @O_iErrorState = 0 /*IF no validation errors then we can proceed to find default values*/
	BEGIN 
		
		/**/
		/*@I_vUSERID: Default User ID to 'sa' if not supplied*/
		IF RTRIM(@I_vUSERID) = '' 
			BEGIN
				SET @I_vUSERID = 'sa'				
			END
		
		/*@I_vME_UserWhoEdited: Default to @I_vUSERID*/
		IF RTRIM(@I_vME_UserWhoEdited) = '' 
			BEGIN
				SET @I_vME_UserWhoEdited = @I_vUSERID
			END
		
		/*Default the statuses to 1*/
		IF @I_vME_View_Status		 = 0 SET @I_vME_View_Status			= 1
		IF @I_vME_EditStatus		 = 0 SET @I_vME_EditStatus			= 1
		IF @I_vME_DistributionStatus = 0 SET @I_vME_DistributionStatus  = 1
		IF @I_vME_AdjustStatus		 = 0 SET @I_vME_AdjustStatus		= 1
	
		/*Budget Statuses default to 1 if PT Budgeting is registered*/
		IF EXISTS (SELECT TOP 1 * FROM ME97739) --ME_Budget_Maint_HDR)
			BEGIN
				SET @I_vME_Budget_Approve_Status = 1
				SET @I_vME_Budget_Edit_Status	 = 1
				SET @I_vME_Budget_Reopen_Status	 = 1
				SET @I_vME_Budget_View_Status	 = 1
			END
			
		/*Job status can default to 1*/
		IF @I_vME_Job_Status = 0 SET @I_vME_Job_Status = 1
		
		/*@I_vSalesPersonID: Default Sales Person ID based on Customer ID if @I_vSalesPersonID is not supplied*/	
		IF @I_vSalesPersonID = '' AND EXISTS (SELECT SLPRSNID FROM RM00101 WHERE CUSTNMBR = RTRIM(UPPER(@I_vCUSTNMBR)))
			BEGIN
				SELECT @I_vSalesPersonID = SLPRSNID
				FROM RM00101 
				WHERE RTRIM(CUSTNMBR) = RTRIM(UPPER(@I_vCUSTNMBR))
			END
		
		/*Set Cust ID and Sales Person ID to UPPERCASE*/
		SET @I_vSalesPersonID = RTRIM(UPPER(@I_vSalesPersonID))
		SET @I_vCUSTNMBR	  = RTRIM(UPPER(@I_vCUSTNMBR))
		
		/*Set User Defined fields to UPPERCASE*/
		SET @I_vME_User_Defined_1 = RTRIM(UPPER(@I_vME_User_Defined_1))
		SET @I_vME_User_Defined_2 = RTRIM(UPPER(@I_vME_User_Defined_2))
		SET @I_vME_User_Defined_3 = RTRIM(UPPER(@I_vME_User_Defined_3))
		SET @I_vME_User_Defined_4 = RTRIM(UPPER(@I_vME_User_Defined_4))
		SET @I_vME_User_Defined_5 = RTRIM(UPPER(@I_vME_User_Defined_5))
		SET @I_vME_User_Defined_6 = RTRIM(UPPER(@I_vME_User_Defined_6))
		SET @I_vME_User_Defined_7 = RTRIM(UPPER(@I_vME_User_Defined_7))
		
		/*@I_vME_Job_Open_Date - Default to current date if empty*/
		IF @I_vME_Job_Open_Date = '01-01-1900' SET @I_vME_Job_Open_Date = CONVERT(DATE, GETDATE())
		
		/*@I_vUSERDATE - Default to modified date*/
		IF @I_vUSERDATE = '01-01-1900' SET @I_vUSERDATE = CONVERT(DATE, GETDATE())
		
		/*@DBNAME - Get the GP Database name*/
		SELECT @DBNAME = DB_NAME()
		
		/*@O_mNoteIndex - Get Note Index*/
		IF RTRIM(@I_vSystemDatabase) = 'DYN01'
			BEGIN
				SELECT @O_vCompanyID = CMPANYID FROM DYN01..SY01500 WHERE INTERID = @DBNAME
				EXEC DYN01..smGetNextNoteIndex @O_vCompanyID, 0, @O_mNoteIndex OUT, @O_iNoteErrorState OUT
			END
		
		IF RTRIM(@I_vSystemDatabase) = 'DYNAMICS'
			BEGIN
				SELECT @O_vCompanyID = CMPANYID FROM DYNAMICS..SY01500 WHERE INTERID = @DBNAME
				EXEC DYNAMICS..smGetNextNoteIndex @O_vCompanyID, 0, @O_mNoteIndex OUT, @O_iNoteErrorState OUT
			END
		
		/*If @I_vSystemDatabase) is not 'DYNAMICS' or 'DYN01' --
		Need to specify System Database - replace '[dbname]' with correct company/system database name*/
		IF RTRIM(@I_vSystemDatabase) NOT IN ('DYNAMICS', 'DYN01')
			BEGIN
				SELECT @O_vCompanyID = CMPANYID FROM [dbname]..SY01500 WHERE INTERID = @DBNAME
				EXEC [dbname]..smGetNextNoteIndex @O_vCompanyID, 0, @O_mNoteIndex OUT, @O_iNoteErrorState OUT
			END
		
		SET @I_vNOTEINDX = @O_mNoteIndex 
	
	-------------------------------
	/*Insert the record into the ME97708 - ME_Job_Cost_OPEN table*/
	INSERT ME97708 (
		 ME_Job_ID                 
		,ME_Job_Open_Date          
		,ME_Job_Close_Date         
		,SLPRSNID                  
		,ME_Proposal_Number        
		,MEuserdefined2            
		,ME_Work_Order_Number      
		,CUSTNMBR                  
		,ME_Used_In_Budgeting_1    
		,ME_Used_In_Budgeting_2    
		,ME_Used_In_Budgeting_3    
		,ME_Used_In_Budgeting_4    
		,ME_Used_In_Budgeting_5    
		,ME_Used_In_Budgeting_6    
		,ME_Used_In_Budgeting_7    
		,ME_Work_Scope             
		,ME_User_Defined           
		,meestoprev                
		,ME_Est_Start_Date         
		,ME_Est_Complete_Date      
		,ME_Actual_Start_Date      
		,ME_Actual_End_Date        
		,ME_Actual_Operating_Reve  
		,ME_Actual_Sales_Tax       
		,ME_Est_Cost_Labor         
		,ME_Est_Cost_Material      
		,ME_Orig_Est_Cost_Labo     
		,ME_Orig_Est_Cost_Mate     
		,ME_Actual_Cost_Labor      
		,ME_Actual_Cost_Material   
		,FRTAMNT                   
		,MISCAMNT                  
		,TRDISAMT                  
		,MEuserdefined3            
		,MEuserdefined1            
		,NOTEINDX                  
		,ME_Op_Cost__Revenue       
		,ME_Op_Cost__CostLabor     
		,ME_Op_Cost__Cost_Materie  
		,ME_Adjustments            
		,ME_User_Defined_5         
		,ME_User_Defined_6         
		,ME_User_Defined_7         
		,ME_Job_Status             
		,ME_Actual_Rev_Collected   
		,ME_Reporting              
		,ME_WIP_Account_Ind        
		,ME_CB_Udefs_1             
		,ME_CB_Udefs_2             
		,ME_CB_Udefs_3             
		,ME_CB_Udefs_4             
		,ME_CB_Udefs_5             
		,ME_CB_Udefs_6             
		,ME_CB_Udefs_7             
		,ME_Date_Udefs_1           
		,ME_Date_Udefs_2           
		,ME_Date_Udefs_3           
		,ME_Date_Udefs_4           
		,ME_Date_Udefs_5           
		,ME_Date_Udefs_6           
		,ME_Date_Udefs_7           
		,ME_Numeric_Udefs_1        
		,ME_Numeric_Udefs_2        
		,ME_Numeric_Udefs_3        
		,ME_Numeric_Udefs_4        
		,ME_Numeric_Udefs_5        
		,ME_Numeric_Udefs_6        
		,ME_Numeric_Udefs_7        
		,ME_User_Defined_Budget_C_1
		,ME_User_Defined_Budget_C_2
		,ME_User_Defined_Budget_C_3
		,ME_User_Defined_Budget_C_4
		,ME_User_Defined_Budget_C_5
		,ME_User_Defined_Budget_C_6
		,ME_User_Defined_Budget_C_7
		,DEFAULTGRANTID)
	 VALUES ( 
		@I_vME_Job_ID                 
		,@I_vME_Job_Open_Date          
		,@I_vME_Job_Close_Date         
		,@I_vSalesPersonID                  
		,@I_vME_Proposal_Number        
		,@I_vME_User_Defined_2            
		,@I_vME_Work_Order_Number      
		,@I_vCUSTNMBR
		,@I_vME_Used_In_Budgeting_1    
		,@I_vME_Used_In_Budgeting_2    
		,@I_vME_Used_In_Budgeting_3    
		,@I_vME_Used_In_Budgeting_4    
		,@I_vME_Used_In_Budgeting_5    
		,@I_vME_Used_In_Budgeting_6    
		,@I_vME_Used_In_Budgeting_7    
		,@I_vME_Description             
		,@I_vME_User_Defined_1           
		,@I_vME_Est_Operating_Revenue                
		,@I_vME_Est_Start_Date         
		,@I_vME_Est_Complete_Date      
		,@I_vME_Actual_Start_Date      
		,@I_vME_Actual_End_Date        
		,@I_vME_Actual_Operating_Reve  
		,@I_vME_Actual_Sales_Tax       
		,@I_vME_Est_Cost_Labor         
		,@I_vME_Est_Cost_Material      
		,@I_vME_Orig_Est_Cost_Labo     
		,@I_vME_Orig_Est_Cost_Mate     
		,@I_vME_Actual_Cost_Labor      
		,@I_vME_Actual_Cost_Material   
		,@I_vFRTAMNT                   
		,@I_vMISCAMNT                  
		,@I_vTRDISAMT                  
		,@I_vME_User_Defined_3            
		,@I_vME_User_Defined_4            
		,@I_vNOTEINDX                  
		,@I_vME_Op_Cost__Revenue       
		,@I_vME_Op_Cost__CostLabor     
		,@I_vME_Op_Cost__Cost_Materie  
		,@I_vME_Adjustments            
		,@I_vME_User_Defined_5         
		,@I_vME_User_Defined_6         
		,@I_vME_User_Defined_7         
		,@I_vME_Job_Status             
		,@I_vME_Actual_Rev_Collected   
		,@I_vME_Exclude_From_Reports              
		,@I_vME_WIP_Account_Ind        
		,@I_vME_CB_Udefs_1             
		,@I_vME_CB_Udefs_2             
		,@I_vME_CB_Udefs_3             
		,@I_vME_CB_Udefs_4             
		,@I_vME_CB_Udefs_5             
		,@I_vME_CB_Udefs_6             
		,@I_vME_CB_Udefs_7             
		,@I_vME_Date_Udefs_1           
		,@I_vME_Date_Udefs_2           
		,@I_vME_Date_Udefs_3           
		,@I_vME_Date_Udefs_4           
		,@I_vME_Date_Udefs_5           
		,@I_vME_Date_Udefs_6           
		,@I_vME_Date_Udefs_7           
		,@I_vME_Numeric_Udefs_1        
		,@I_vME_Numeric_Udefs_2        
		,@I_vME_Numeric_Udefs_3        
		,@I_vME_Numeric_Udefs_4        
		,@I_vME_Numeric_Udefs_5        
		,@I_vME_Numeric_Udefs_6        
		,@I_vME_Numeric_Udefs_7        
		,@I_vME_User_Defined_Constant_1
		,@I_vME_User_Defined_Constant_2
		,@I_vME_User_Defined_Constant_3
		,@I_vME_User_Defined_Constant_4
		,@I_vME_User_Defined_Constant_5
		,@I_vME_User_Defined_Constant_6
		,@I_vME_User_Defined_Constant_7
		,@I_vDEFAULTGRANTID)
		
		
		/*Create_New_Security_Setup - ME97735 -- ME_Project_User_Projects*/
		INSERT ME97735 (
			USERID
			,ME_Job_ID
			,ME_View_Status
			,ME_EditStatus
			,ME_DistributionStatus
			,ME_Budget_Approve_Status
			,ME_Budget_Edit_Status
			,ME_Budget_Reopen_Status
			,ME_Budget_View_Status
			,ME_AdjustStatus
			,ME_UserWhoEdited
			,USERDATE)
		VALUES(
			@I_vUSERID
			,@I_vME_Job_ID
			,@I_vME_View_Status
			,@I_vME_EditStatus
			,@I_vME_DistributionStatus
			,@I_vME_Budget_Approve_Status
			,@I_vME_Budget_Edit_Status
			,@I_vME_Budget_Reopen_Status
			,@I_vME_Budget_View_Status
			,@I_vME_AdjustStatus
			,@I_vME_UserWhoEdited
			,@I_vUSERDATE)
	END